# -*- coding: utf-8 -*-
# Copyright 2022 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
from typing import MutableMapping, MutableSequence

import proto  # type: ignore

from google.cloud.talent_v4.types import common

__protobuf__ = proto.module(
    package="google.cloud.talent.v4",
    manifest={
        "Company",
    },
)


class Company(proto.Message):
    r"""A Company resource represents a company in the service. A
    company is the entity that owns job postings, that is, the
    hiring entity responsible for employing applicants for the job
    position.

    Attributes:
        name (str):
            Required during company update.

            The resource name for a company. This is generated by the
            service when a company is created.

            The format is
            "projects/{project_id}/tenants/{tenant_id}/companies/{company_id}",
            for example, "projects/foo/tenants/bar/companies/baz".
        display_name (str):
            Required. The display name of the company,
            for example, "Google LLC".
        external_id (str):
            Required. Client side company identifier,
            used to uniquely identify the company.

            The maximum number of allowed characters is 255.
        size (google.cloud.talent_v4.types.CompanySize):
            The employer's company size.
        headquarters_address (str):
            The street address of the company's main headquarters, which
            may be different from the job location. The service attempts
            to geolocate the provided address, and populates a more
            specific location wherever possible in
            [DerivedInfo.headquarters_location][google.cloud.talent.v4.Company.DerivedInfo.headquarters_location].
        hiring_agency (bool):
            Set to true if it is the hiring agency that
            post jobs for other employers.

            Defaults to false if not provided.
        eeo_text (str):
            Equal Employment Opportunity legal disclaimer
            text to be associated with all jobs, and
            typically to be displayed in all roles.

            The maximum number of allowed characters is 500.
        website_uri (str):
            The URI representing the company's primary
            web site or home page, for example,
            "https://www.google.com".
            The maximum number of allowed characters is 255.
        career_site_uri (str):
            The URI to employer's career site or careers
            page on the employer's web site, for example,
            "https://careers.google.com".
        image_uri (str):
            A URI that hosts the employer's company logo.
        keyword_searchable_job_custom_attributes (MutableSequence[str]):
            This field is deprecated. Please set the searchability of
            the custom attribute in the
            [Job.custom_attributes][google.cloud.talent.v4.Job.custom_attributes]
            going forward.

            A list of keys of filterable
            [Job.custom_attributes][google.cloud.talent.v4.Job.custom_attributes],
            whose corresponding ``string_values`` are used in keyword
            searches. Jobs with ``string_values`` under these specified
            field keys are returned if any of the values match the
            search keyword. Custom field values with parenthesis,
            brackets and special symbols are not searchable as-is, and
            those keyword queries must be surrounded by quotes.
        derived_info (google.cloud.talent_v4.types.Company.DerivedInfo):
            Output only. Derived details about the
            company.
        suspended (bool):
            Output only. Indicates whether a company is
            flagged to be suspended from public availability
            by the service when job content appears
            suspicious, abusive, or spammy.
    """

    class DerivedInfo(proto.Message):
        r"""Derived details about the company.

        Attributes:
            headquarters_location (google.cloud.talent_v4.types.Location):
                A structured headquarters location of the company, resolved
                from
                [Company.headquarters_address][google.cloud.talent.v4.Company.headquarters_address]
                if provided.
        """

        headquarters_location: common.Location = proto.Field(
            proto.MESSAGE,
            number=1,
            message=common.Location,
        )

    name: str = proto.Field(
        proto.STRING,
        number=1,
    )
    display_name: str = proto.Field(
        proto.STRING,
        number=2,
    )
    external_id: str = proto.Field(
        proto.STRING,
        number=3,
    )
    size: common.CompanySize = proto.Field(
        proto.ENUM,
        number=4,
        enum=common.CompanySize,
    )
    headquarters_address: str = proto.Field(
        proto.STRING,
        number=5,
    )
    hiring_agency: bool = proto.Field(
        proto.BOOL,
        number=6,
    )
    eeo_text: str = proto.Field(
        proto.STRING,
        number=7,
    )
    website_uri: str = proto.Field(
        proto.STRING,
        number=8,
    )
    career_site_uri: str = proto.Field(
        proto.STRING,
        number=9,
    )
    image_uri: str = proto.Field(
        proto.STRING,
        number=10,
    )
    keyword_searchable_job_custom_attributes: MutableSequence[
        str
    ] = proto.RepeatedField(
        proto.STRING,
        number=11,
    )
    derived_info: DerivedInfo = proto.Field(
        proto.MESSAGE,
        number=12,
        message=DerivedInfo,
    )
    suspended: bool = proto.Field(
        proto.BOOL,
        number=13,
    )


__all__ = tuple(sorted(__protobuf__.manifest))



# -*- coding: utf-8 -*-
# Copyright 2022 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
from typing import MutableMapping, MutableSequence

import proto  # type: ignore

__protobuf__ = proto.module(
    package="google.cloud.talent.v4beta1",
    manifest={
        "HistogramQuery",
        "HistogramQueryResult",
    },
)


class HistogramQuery(proto.Message):
    r"""The histogram request.

    Attributes:
        histogram_query (str):
            An expression specifies a histogram request against matching
            resources (for example, jobs, profiles) for searches.

            See
            [SearchJobsRequest.histogram_queries][google.cloud.talent.v4beta1.SearchJobsRequest.histogram_queries]
            and
            [SearchProfilesRequest.histogram_queries][google.cloud.talent.v4beta1.SearchProfilesRequest.histogram_queries]
            for details about syntax.
    """

    histogram_query: str = proto.Field(
        proto.STRING,
        number=1,
    )


class HistogramQueryResult(proto.Message):
    r"""Histogram result that matches
    [HistogramQuery][google.cloud.talent.v4beta1.HistogramQuery]
    specified in searches.

    Attributes:
        histogram_query (str):
            Requested histogram expression.
        histogram (MutableMapping[str, int]):
            A map from the values of the facet associated with distinct
            values to the number of matching entries with corresponding
            value.

            The key format is:

            -  (for string histogram) string values stored in the field.
            -  (for named numeric bucket) name specified in ``bucket()``
               function, like for ``bucket(0, MAX, "non-negative")``,
               the key will be ``non-negative``.
            -  (for anonymous numeric bucket) range formatted as
               ``<low>-<high>``, for example, ``0-1000``, ``MIN-0``, and
               ``0-MAX``.
    """

    histogram_query: str = proto.Field(
        proto.STRING,
        number=1,
    )
    histogram: MutableMapping[str, int] = proto.MapField(
        proto.STRING,
        proto.INT64,
        number=2,
    )


__all__ = tuple(sorted(__protobuf__.manifest))



# -*- coding: utf-8 -*-
# Copyright 2022 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
from typing import MutableMapping, MutableSequence

from google.protobuf import duration_pb2  # type: ignore
from google.protobuf import field_mask_pb2  # type: ignore
from google.rpc import status_pb2  # type: ignore
import proto  # type: ignore

from google.cloud.talent_v4beta1.types import common, filters, histogram
from google.cloud.talent_v4beta1.types import job as gct_job

__protobuf__ = proto.module(
    package="google.cloud.talent.v4beta1",
    manifest={
        "JobView",
        "CreateJobRequest",
        "GetJobRequest",
        "UpdateJobRequest",
        "DeleteJobRequest",
        "BatchDeleteJobsRequest",
        "ListJobsRequest",
        "ListJobsResponse",
        "SearchJobsRequest",
        "SearchJobsResponse",
        "BatchCreateJobsRequest",
        "BatchUpdateJobsRequest",
        "JobOperationResult",
    },
)


class JobView(proto.Enum):
    r"""An enum that specifies the job attributes that are returned in the
    [MatchingJob.job][google.cloud.talent.v4beta1.SearchJobsResponse.MatchingJob.job]
    or
    [ListJobsResponse.jobs][google.cloud.talent.v4beta1.ListJobsResponse.jobs]
    fields.
    """
    JOB_VIEW_UNSPECIFIED = 0
    JOB_VIEW_ID_ONLY = 1
    JOB_VIEW_MINIMAL = 2
    JOB_VIEW_SMALL = 3
    JOB_VIEW_FULL = 4


class CreateJobRequest(proto.Message):
    r"""Create job request.

    Attributes:
        parent (str):
            Required. The resource name of the tenant under which the
            job is created.

            The format is "projects/{project_id}/tenants/{tenant_id}".
            For example, "projects/foo/tenant/bar". If tenant id is
            unspecified a default tenant is created. For example,
            "projects/foo".
        job (google.cloud.talent_v4beta1.types.Job):
            Required. The Job to be created.
    """

    parent: str = proto.Field(
        proto.STRING,
        number=1,
    )
    job: gct_job.Job = proto.Field(
        proto.MESSAGE,
        number=2,
        message=gct_job.Job,
    )


class GetJobRequest(proto.Message):
    r"""Get job request.

    Attributes:
        name (str):
            Required. The resource name of the job to retrieve.

            The format is
            "projects/{project_id}/tenants/{tenant_id}/jobs/{job_id}".
            For example, "projects/foo/tenants/bar/jobs/baz".

            If tenant id is unspecified, the default tenant is used. For
            example, "projects/foo/jobs/bar".
    """

    name: str = proto.Field(
        proto.STRING,
        number=1,
    )


class UpdateJobRequest(proto.Message):
    r"""Update job request.

    Attributes:
        job (google.cloud.talent_v4beta1.types.Job):
            Required. The Job to be updated.
        update_mask (google.protobuf.field_mask_pb2.FieldMask):
            Strongly recommended for the best service experience.

            If
            [update_mask][google.cloud.talent.v4beta1.UpdateJobRequest.update_mask]
            is provided, only the specified fields in
            [job][google.cloud.talent.v4beta1.UpdateJobRequest.job] are
            updated. Otherwise all the fields are updated.

            A field mask to restrict the fields that are updated. Only
            top level fields of [Job][google.cloud.talent.v4beta1.Job]
            are supported.
    """

    job: gct_job.Job = proto.Field(
        proto.MESSAGE,
        number=1,
        message=gct_job.Job,
    )
    update_mask: field_mask_pb2.FieldMask = proto.Field(
        proto.MESSAGE,
        number=2,
        message=field_mask_pb2.FieldMask,
    )


class DeleteJobRequest(proto.Message):
    r"""Delete job request.

    Attributes:
        name (str):
            Required. The resource name of the job to be deleted.

            The format is
            "projects/{project_id}/tenants/{tenant_id}/jobs/{job_id}".
            For example, "projects/foo/tenants/bar/jobs/baz".

            If tenant id is unspecified, the default tenant is used. For
            example, "projects/foo/jobs/bar".
    """

    name: str = proto.Field(
        proto.STRING,
        number=1,
    )


class BatchDeleteJobsRequest(proto.Message):
    r"""Batch delete jobs request.

    Attributes:
        parent (str):
            Required. The resource name of the tenant under which the
            job is created.

            The format is "projects/{project_id}/tenants/{tenant_id}".
            For example, "projects/foo/tenant/bar". If tenant id is
            unspecified, a default tenant is created. For example,
            "projects/foo".
        filter (str):
            Required. The filter string specifies the jobs to be
            deleted.

            Supported operator: =, AND

            The fields eligible for filtering are:

            -  ``companyName`` (Required)
            -  ``requisitionId`` (Required)

            Sample Query: companyName = "projects/foo/companies/bar" AND
            requisitionId = "req-1".
    """

    parent: str = proto.Field(
        proto.STRING,
        number=1,
    )
    filter: str = proto.Field(
        proto.STRING,
        number=2,
    )


class ListJobsRequest(proto.Message):
    r"""List jobs request.

    Attributes:
        parent (str):
            Required. The resource name of the tenant under which the
            job is created.

            The format is "projects/{project_id}/tenants/{tenant_id}".
            For example, "projects/foo/tenant/bar". If tenant id is
            unspecified, a default tenant is created. For example,
            "projects/foo".
        filter (str):
            Required. The filter string specifies the jobs to be
            enumerated.

            Supported operator: =, AND

            The fields eligible for filtering are:

            -  ``companyName``
            -  ``requisitionId``
            -  ``status`` Available values: OPEN, EXPIRED, ALL. Defaults
               to OPEN if no value is specified.

            At least one of ``companyName`` and ``requisitionId`` must
            present or an INVALID_ARGUMENT error is thrown.

            Sample Query:

            -  companyName = "projects/foo/tenants/bar/companies/baz"
            -  companyName = "projects/foo/tenants/bar/companies/baz"
               AND requisitionId = "req-1"
            -  companyName = "projects/foo/tenants/bar/companies/baz"
               AND status = "EXPIRED"
            -  requisitionId = "req-1"
            -  requisitionId = "req-1" AND status = "EXPIRED".
        page_token (str):
            The starting point of a query result.
        page_size (int):
            The maximum number of jobs to be returned per page of
            results.

            If
            [job_view][google.cloud.talent.v4beta1.ListJobsRequest.job_view]
            is set to
            [JobView.JOB_VIEW_ID_ONLY][google.cloud.talent.v4beta1.JobView.JOB_VIEW_ID_ONLY],
            the maximum allowed page size is 1000. Otherwise, the
            maximum allowed page size is 100.

            Default is 100 if empty or a number < 1 is specified.
        job_view (google.cloud.talent_v4beta1.types.JobView):
            The desired job attributes returned for jobs in the search
            response. Defaults to
            [JobView.JOB_VIEW_FULL][google.cloud.talent.v4beta1.JobView.JOB_VIEW_FULL]
            if no value is specified.
    """

    parent: str = proto.Field(
        proto.STRING,
        number=1,
    )
    filter: str = proto.Field(
        proto.STRING,
        number=2,
    )
    page_token: str = proto.Field(
        proto.STRING,
        number=3,
    )
    page_size: int = proto.Field(
        proto.INT32,
        number=4,
    )
    job_view: "JobView" = proto.Field(
        proto.ENUM,
        number=5,
        enum="JobView",
    )


class ListJobsResponse(proto.Message):
    r"""List jobs response.

    Attributes:
        jobs (MutableSequence[google.cloud.talent_v4beta1.types.Job]):
            The Jobs for a given company.
            The maximum number of items returned is based on
            the limit field provided in the request.
        next_page_token (str):
            A token to retrieve the next page of results.
        metadata (google.cloud.talent_v4beta1.types.ResponseMetadata):
            Additional information for the API
            invocation, such as the request tracking id.
    """

    @property
    def raw_page(self):
        return self

    jobs: MutableSequence[gct_job.Job] = proto.RepeatedField(
        proto.MESSAGE,
        number=1,
        message=gct_job.Job,
    )
    next_page_token: str = proto.Field(
        proto.STRING,
        number=2,
    )
    metadata: common.ResponseMetadata = proto.Field(
        proto.MESSAGE,
        number=3,
        message=common.ResponseMetadata,
    )


class SearchJobsRequest(proto.Message):
    r"""The Request body of the ``SearchJobs`` call.

    Attributes:
        parent (str):
            Required. The resource name of the tenant to search within.

            The format is "projects/{project_id}/tenants/{tenant_id}".
            For example, "projects/foo/tenant/bar". If tenant id is
            unspecified, a default tenant is created. For example,
            "projects/foo".
        search_mode (google.cloud.talent_v4beta1.types.SearchJobsRequest.SearchMode):
            Mode of a search.

            Defaults to
            [SearchMode.JOB_SEARCH][google.cloud.talent.v4beta1.SearchJobsRequest.SearchMode.JOB_SEARCH].
        request_metadata (google.cloud.talent_v4beta1.types.RequestMetadata):
            Required. The meta information collected about the job
            searcher, used to improve the search quality of the service.
            The identifiers (such as ``user_id``) are provided by users,
            and must be unique and consistent.
        job_query (google.cloud.talent_v4beta1.types.JobQuery):
            Query used to search against jobs, such as
            keyword, location filters, etc.
        enable_broadening (bool):
            Controls whether to broaden the search when
            it produces sparse results. Broadened queries
            append results to the end of the matching
            results list.

            Defaults to false.
        require_precise_result_size (bool):
            This field is deprecated.
        histogram_queries (MutableSequence[google.cloud.talent_v4beta1.types.HistogramQuery]):
            An expression specifies a histogram request against matching
            jobs.

            Expression syntax is an aggregation function call with
            histogram facets and other options.

            Available aggregation function calls are:

            -  ``count(string_histogram_facet)``: Count the number of
               matching entities, for each distinct attribute value.
            -  ``count(numeric_histogram_facet, list of buckets)``:
               Count the number of matching entities within each bucket.

            A maximum of 200 histogram buckets are supported.

            Data types:

            -  Histogram facet: facet names with format
               ``[a-zA-Z][a-zA-Z0-9_]+``.
            -  String: string like "any string with backslash escape for
               quote(")."
            -  Number: whole number and floating point number like 10,
               -1 and -0.01.
            -  List: list of elements with comma(,) separator surrounded
               by square brackets, for example, [1, 2, 3] and ["one",
               "two", "three"].

            Built-in constants:

            -  MIN (minimum number similar to java Double.MIN_VALUE)
            -  MAX (maximum number similar to java Double.MAX_VALUE)

            Built-in functions:

            -  bucket(start, end[, label]): bucket built-in function
               creates a bucket with range of [start, end). Note that
               the end is exclusive, for example, bucket(1, MAX,
               "positive number") or bucket(1, 10).

            Job histogram facets:

            -  company_display_name: histogram by
               [Job.company_display_name][google.cloud.talent.v4beta1.Job.company_display_name].
            -  employment_type: histogram by
               [Job.employment_types][google.cloud.talent.v4beta1.Job.employment_types],
               for example, "FULL_TIME", "PART_TIME".
            -  company_size (DEPRECATED): histogram by
               [CompanySize][google.cloud.talent.v4beta1.CompanySize],
               for example, "SMALL", "MEDIUM", "BIG".
            -  publish_time_in_day: histogram by the
               [Job.posting_publish_time][google.cloud.talent.v4beta1.Job.posting_publish_time]
               in days. Must specify list of numeric buckets in spec.
            -  publish_time_in_month: histogram by the
               [Job.posting_publish_time][google.cloud.talent.v4beta1.Job.posting_publish_time]
               in months. Must specify list of numeric buckets in spec.
            -  publish_time_in_year: histogram by the
               [Job.posting_publish_time][google.cloud.talent.v4beta1.Job.posting_publish_time]
               in years. Must specify list of numeric buckets in spec.
            -  degree_types: histogram by the
               [Job.degree_types][google.cloud.talent.v4beta1.Job.degree_types],
               for example, "Bachelors", "Masters".
            -  job_level: histogram by the
               [Job.job_level][google.cloud.talent.v4beta1.Job.job_level],
               for example, "Entry Level".
            -  country: histogram by the country code of jobs, for
               example, "US", "FR".
            -  admin1: histogram by the admin1 code of jobs, which is a
               global placeholder referring to the state, province, or
               the particular term a country uses to define the
               geographic structure below the country level, for
               example, "CA", "IL".
            -  city: histogram by a combination of the "city name,
               admin1 code". For example, "Mountain View, CA", "New
               York, NY".
            -  admin1_country: histogram by a combination of the "admin1
               code, country", for example, "CA, US", "IL, US".
            -  city_coordinate: histogram by the city center's GPS
               coordinates (latitude and longitude), for example,
               37.4038522,-122.0987765. Since the coordinates of a city
               center can change, customers may need to refresh them
               periodically.
            -  locale: histogram by the
               [Job.language_code][google.cloud.talent.v4beta1.Job.language_code],
               for example, "en-US", "fr-FR".
            -  language: histogram by the language subtag of the
               [Job.language_code][google.cloud.talent.v4beta1.Job.language_code],
               for example, "en", "fr".
            -  category: histogram by the
               [JobCategory][google.cloud.talent.v4beta1.JobCategory],
               for example, "COMPUTER_AND_IT", "HEALTHCARE".
            -  base_compensation_unit: histogram by the
               [CompensationInfo.CompensationUnit][google.cloud.talent.v4beta1.CompensationInfo.CompensationUnit]
               of base salary, for example, "WEEKLY", "MONTHLY".
            -  base_compensation: histogram by the base salary. Must
               specify list of numeric buckets to group results by.
            -  annualized_base_compensation: histogram by the base
               annualized salary. Must specify list of numeric buckets
               to group results by.
            -  annualized_total_compensation: histogram by the total
               annualized salary. Must specify list of numeric buckets
               to group results by.
            -  string_custom_attribute: histogram by string
               [Job.custom_attributes][google.cloud.talent.v4beta1.Job.custom_attributes].
               Values can be accessed via square bracket notations like
               string_custom_attribute["key1"].
            -  numeric_custom_attribute: histogram by numeric
               [Job.custom_attributes][google.cloud.talent.v4beta1.Job.custom_attributes].
               Values can be accessed via square bracket notations like
               numeric_custom_attribute["key1"]. Must specify list of
               numeric buckets to group results by.

            Example expressions:

            -  ``count(admin1)``
            -  ``count(base_compensation, [bucket(1000, 10000), bucket(10000, 100000), bucket(100000, MAX)])``
            -  ``count(string_custom_attribute["some-string-custom-attribute"])``
            -  ``count(numeric_custom_attribute["some-numeric-custom-attribute"], [bucket(MIN, 0, "negative"), bucket(0, MAX, "non-negative")])``
        job_view (google.cloud.talent_v4beta1.types.JobView):
            The desired job attributes returned for jobs in the search
            response. Defaults to
            [JobView.JOB_VIEW_SMALL][google.cloud.talent.v4beta1.JobView.JOB_VIEW_SMALL]
            if no value is specified.
        offset (int):
            An integer that specifies the current offset (that is,
            starting result location, amongst the jobs deemed by the API
            as relevant) in search results. This field is only
            considered if
            [page_token][google.cloud.talent.v4beta1.SearchJobsRequest.page_token]
            is unset.

            The maximum allowed value is 5000. Otherwise an error is
            thrown.

            For example, 0 means to return results starting from the
            first matching job, and 10 means to return from the 11th
            job. This can be used for pagination, (for example, pageSize
            = 10 and offset = 10 means to return from the second page).
        page_size (int):
            A limit on the number of jobs returned in the
            search results. Increasing this value above the
            default value of 10 can increase search response
            time. The value can be between 1 and 100.
        page_token (str):
            The token specifying the current offset within search
            results. See
            [SearchJobsResponse.next_page_token][google.cloud.talent.v4beta1.SearchJobsResponse.next_page_token]
            for an explanation of how to obtain the next set of query
            results.
        order_by (str):
            The criteria determining how search results are sorted.
            Default is ``"relevance desc"``.

            Supported options are:

            -  ``"relevance desc"``: By relevance descending, as
               determined by the API algorithms. Relevance thresholding
               of query results is only available with this ordering.
            -  ``"posting_publish_time desc"``: By
               [Job.posting_publish_time][google.cloud.talent.v4beta1.Job.posting_publish_time]
               descending.
            -  ``"posting_update_time desc"``: By
               [Job.posting_update_time][google.cloud.talent.v4beta1.Job.posting_update_time]
               descending.
            -  ``"title"``: By
               [Job.title][google.cloud.talent.v4beta1.Job.title]
               ascending.
            -  ``"title desc"``: By
               [Job.title][google.cloud.talent.v4beta1.Job.title]
               descending.
            -  ``"annualized_base_compensation"``: By job's
               [CompensationInfo.annualized_base_compensation_range][google.cloud.talent.v4beta1.CompensationInfo.annualized_base_compensation_range]
               ascending. Jobs whose annualized base compensation is
               unspecified are put at the end of search results.
            -  ``"annualized_base_compensation desc"``: By job's
               [CompensationInfo.annualized_base_compensation_range][google.cloud.talent.v4beta1.CompensationInfo.annualized_base_compensation_range]
               descending. Jobs whose annualized base compensation is
               unspecified are put at the end of search results.
            -  ``"annualized_total_compensation"``: By job's
               [CompensationInfo.annualized_total_compensation_range][google.cloud.talent.v4beta1.CompensationInfo.annualized_total_compensation_range]
               ascending. Jobs whose annualized base compensation is
               unspecified are put at the end of search results.
            -  ``"annualized_total_compensation desc"``: By job's
               [CompensationInfo.annualized_total_compensation_range][google.cloud.talent.v4beta1.CompensationInfo.annualized_total_compensation_range]
               descending. Jobs whose annualized base compensation is
               unspecified are put at the end of search results.
            -  ``"custom_ranking desc"``: By the relevance score
               adjusted to the
               [SearchJobsRequest.CustomRankingInfo.ranking_expression][google.cloud.talent.v4beta1.SearchJobsRequest.CustomRankingInfo.ranking_expression]
               with weight factor assigned by
               [SearchJobsRequest.CustomRankingInfo.importance_level][google.cloud.talent.v4beta1.SearchJobsRequest.CustomRankingInfo.importance_level]
               in descending order.
            -  Location sorting: Use the special syntax to order jobs by
               distance: ``"distance_from('Hawaii')"``: Order by
               distance from Hawaii. ``"distance_from(19.89, 155.5)"``:
               Order by distance from a coordinate.
               ``"distance_from('Hawaii'), distance_from('Puerto Rico')"``:
               Order by multiple locations. See details below.
               ``"distance_from('Hawaii'), distance_from(19.89, 155.5)"``:
               Order by multiple locations. See details below. The
               string can have a maximum of 256 characters. When
               multiple distance centers are provided, a job that is
               close to any of the distance centers would have a high
               rank. When a job has multiple locations, the job location
               closest to one of the distance centers will be used. Jobs
               that don't have locations will be ranked at the bottom.
               Distance is calculated with a precision of 11.3 meters
               (37.4 feet). Diversification strategy is still applied
               unless explicitly disabled in
               [diversification_level][google.cloud.talent.v4beta1.SearchJobsRequest.diversification_level].
        diversification_level (google.cloud.talent_v4beta1.types.SearchJobsRequest.DiversificationLevel):
            Controls whether highly similar jobs are returned next to
            each other in the search results. Jobs are identified as
            highly similar based on their titles, job categories, and
            locations. Highly similar results are clustered so that only
            one representative job of the cluster is displayed to the
            job seeker higher up in the results, with the other jobs
            being displayed lower down in the results.

            Defaults to
            [DiversificationLevel.SIMPLE][google.cloud.talent.v4beta1.SearchJobsRequest.DiversificationLevel.SIMPLE]
            if no value is specified.
        custom_ranking_info (google.cloud.talent_v4beta1.types.SearchJobsRequest.CustomRankingInfo):
            Controls over how job documents get ranked on
            top of existing relevance score (determined by
            API algorithm).
        disable_keyword_match (bool):
            This field is deprecated. Please use
            [SearchJobsRequest.keyword_match_mode][google.cloud.talent.v4beta1.SearchJobsRequest.keyword_match_mode]
            going forward.

            To migrate, disable_keyword_match set to false maps to
            [KeywordMatchMode.KEYWORD_MATCH_ALL][google.cloud.talent.v4beta1.SearchJobsRequest.KeywordMatchMode.KEYWORD_MATCH_ALL],
            and disable_keyword_match set to true maps to
            [KeywordMatchMode.KEYWORD_MATCH_DISABLED][google.cloud.talent.v4beta1.SearchJobsRequest.KeywordMatchMode.KEYWORD_MATCH_DISABLED].
            If
            [SearchJobsRequest.keyword_match_mode][google.cloud.talent.v4beta1.SearchJobsRequest.keyword_match_mode]
            is set, this field is ignored.

            Controls whether to disable exact keyword match on
            [Job.title][google.cloud.talent.v4beta1.Job.title],
            [Job.description][google.cloud.talent.v4beta1.Job.description],
            [Job.company_display_name][google.cloud.talent.v4beta1.Job.company_display_name],
            [Job.addresses][google.cloud.talent.v4beta1.Job.addresses],
            [Job.qualifications][google.cloud.talent.v4beta1.Job.qualifications].
            When disable keyword match is turned off, a keyword match
            returns jobs that do not match given category filters when
            there are matching keywords. For example, for the query
            "program manager," a result is returned even if the job
            posting has the title "software developer," which doesn't
            fall into "program manager" ontology, but does have "program
            manager" appearing in its description.

            For queries like "cloud" that don't contain title or
            location specific ontology, jobs with "cloud" keyword
            matches are returned regardless of this flag's value.

            Use
            [Company.keyword_searchable_job_custom_attributes][google.cloud.talent.v4beta1.Company.keyword_searchable_job_custom_attributes]
            if company-specific globally matched custom field/attribute
            string values are needed. Enabling keyword match improves
            recall of subsequent search requests.

            Defaults to false.
        keyword_match_mode (google.cloud.talent_v4beta1.types.SearchJobsRequest.KeywordMatchMode):
            Controls what keyword match options to use.

            Defaults to
            [KeywordMatchMode.KEYWORD_MATCH_ALL][google.cloud.talent.v4beta1.SearchJobsRequest.KeywordMatchMode.KEYWORD_MATCH_ALL]
            if no value is specified.
    """

    class SearchMode(proto.Enum):
        r"""A string-represented enumeration of the job search mode. The
        service operate differently for different modes of service.
        """
        SEARCH_MODE_UNSPECIFIED = 0
        JOB_SEARCH = 1
        FEATURED_JOB_SEARCH = 2

    class DiversificationLevel(proto.Enum):
        r"""Controls whether highly similar jobs are returned next to
        each other in the search results. Jobs are identified as highly
        similar based on their titles, job categories, and locations.
        Highly similar results are clustered so that only one
        representative job of the cluster is displayed to the job seeker
        higher up in the results, with the other jobs being displayed
        lower down in the results.
        """
        DIVERSIFICATION_LEVEL_UNSPECIFIED = 0
        DISABLED = 1
        SIMPLE = 2

    class KeywordMatchMode(proto.Enum):
        r"""Controls what keyword matching behavior the search has. When keyword
        matching is enabled, a keyword match returns jobs that may not match
        given category filters when there are matching keywords. For
        example, for the query "program manager" with KeywordMatchMode set
        to KEYWORD_MATCH_ALL, a job posting with the title "software
        developer," which doesn't fall into "program manager" ontology, and
        "program manager" appearing in its description will be surfaced.

        For queries like "cloud" that don't contain title or location
        specific ontology, jobs with "cloud" keyword matches are returned
        regardless of this enum's value.

        Use
        [Company.keyword_searchable_job_custom_attributes][google.cloud.talent.v4beta1.Company.keyword_searchable_job_custom_attributes]
        if company-specific globally matched custom field/attribute string
        values are needed. Enabling keyword match improves recall of
        subsequent search requests.
        """
        KEYWORD_MATCH_MODE_UNSPECIFIED = 0
        KEYWORD_MATCH_DISABLED = 1
        KEYWORD_MATCH_ALL = 2
        KEYWORD_MATCH_TITLE_ONLY = 3

    class CustomRankingInfo(proto.Message):
        r"""Custom ranking information for
        [SearchJobsRequest][google.cloud.talent.v4beta1.SearchJobsRequest].

        Attributes:
            importance_level (google.cloud.talent_v4beta1.types.SearchJobsRequest.CustomRankingInfo.ImportanceLevel):
                Required. Controls over how important the score of
                [CustomRankingInfo.ranking_expression][google.cloud.talent.v4beta1.SearchJobsRequest.CustomRankingInfo.ranking_expression]
                gets applied to job's final ranking position.

                An error is thrown if not specified.
            ranking_expression (str):
                Required. Controls over how job documents get ranked on top
                of existing relevance score (determined by API algorithm). A
                combination of the ranking expression and relevance score is
                used to determine job's final ranking position.

                The syntax for this expression is a subset of Google SQL
                syntax.

                Supported operators are: +, -, \*, /, where the left and
                right side of the operator is either a numeric
                [Job.custom_attributes][google.cloud.talent.v4beta1.Job.custom_attributes]
                key, integer/double value or an expression that can be
                evaluated to a number.

                Parenthesis are supported to adjust calculation precedence.
                The expression must be < 200 characters in length.

                The expression is considered invalid for a job if the
                expression references custom attributes that are not
                populated on the job or if the expression results in a
                divide by zero. If an expression is invalid for a job, that
                job is demoted to the end of the results.

                Sample ranking expression (year + 25) \* 0.25 - (freshness /
                0.5)
        """

        class ImportanceLevel(proto.Enum):
            r"""The importance level for
            [CustomRankingInfo.ranking_expression][google.cloud.talent.v4beta1.SearchJobsRequest.CustomRankingInfo.ranking_expression].
            """
            IMPORTANCE_LEVEL_UNSPECIFIED = 0
            NONE = 1
            LOW = 2
            MILD = 3
            MEDIUM = 4
            HIGH = 5
            EXTREME = 6

        importance_level: "SearchJobsRequest.CustomRankingInfo.ImportanceLevel" = (
            proto.Field(
                proto.ENUM,
                number=1,
                enum="SearchJobsRequest.CustomRankingInfo.ImportanceLevel",
            )
        )
        ranking_expression: str = proto.Field(
            proto.STRING,
            number=2,
        )

    parent: str = proto.Field(
        proto.STRING,
        number=1,
    )
    search_mode: SearchMode = proto.Field(
        proto.ENUM,
        number=2,
        enum=SearchMode,
    )
    request_metadata: common.RequestMetadata = proto.Field(
        proto.MESSAGE,
        number=3,
        message=common.RequestMetadata,
    )
    job_query: filters.JobQuery = proto.Field(
        proto.MESSAGE,
        number=4,
        message=filters.JobQuery,
    )
    enable_broadening: bool = proto.Field(
        proto.BOOL,
        number=5,
    )
    require_precise_result_size: bool = proto.Field(
        proto.BOOL,
        number=6,
    )
    histogram_queries: MutableSequence[histogram.HistogramQuery] = proto.RepeatedField(
        proto.MESSAGE,
        number=7,
        message=histogram.HistogramQuery,
    )
    job_view: "JobView" = proto.Field(
        proto.ENUM,
        number=8,
        enum="JobView",
    )
    offset: int = proto.Field(
        proto.INT32,
        number=9,
    )
    page_size: int = proto.Field(
        proto.INT32,
        number=10,
    )
    page_token: str = proto.Field(
        proto.STRING,
        number=11,
    )
    order_by: str = proto.Field(
        proto.STRING,
        number=12,
    )
    diversification_level: DiversificationLevel = proto.Field(
        proto.ENUM,
        number=13,
        enum=DiversificationLevel,
    )
    custom_ranking_info: CustomRankingInfo = proto.Field(
        proto.MESSAGE,
        number=14,
        message=CustomRankingInfo,
    )
    disable_keyword_match: bool = proto.Field(
        proto.BOOL,
        number=16,
    )
    keyword_match_mode: KeywordMatchMode = proto.Field(
        proto.ENUM,
        number=18,
        enum=KeywordMatchMode,
    )


class SearchJobsResponse(proto.Message):
    r"""Response for SearchJob method.

    Attributes:
        matching_jobs (MutableSequence[google.cloud.talent_v4beta1.types.SearchJobsResponse.MatchingJob]):
            The Job entities that match the specified
            [SearchJobsRequest][google.cloud.talent.v4beta1.SearchJobsRequest].
        histogram_query_results (MutableSequence[google.cloud.talent_v4beta1.types.HistogramQueryResult]):
            The histogram results that match with specified
            [SearchJobsRequest.histogram_queries][google.cloud.talent.v4beta1.SearchJobsRequest.histogram_queries].
        next_page_token (str):
            The token that specifies the starting
            position of the next page of results. This field
            is empty if there are no more results.
        location_filters (MutableSequence[google.cloud.talent_v4beta1.types.Location]):
            The location filters that the service applied to the
            specified query. If any filters are lat-lng based, the
            [Location.location_type][google.cloud.talent.v4beta1.Location.location_type]
            is
            [Location.LocationType.LOCATION_TYPE_UNSPECIFIED][google.cloud.talent.v4beta1.Location.LocationType.LOCATION_TYPE_UNSPECIFIED].
        estimated_total_size (int):
            An estimation of the number of jobs that match the specified
            query.

            This number isn't guaranteed to be accurate. For accurate
            results, see
            [SearchJobsResponse.total_size][google.cloud.talent.v4beta1.SearchJobsResponse.total_size].
        total_size (int):
            The precise result count with limit 100,000.
        metadata (google.cloud.talent_v4beta1.types.ResponseMetadata):
            Additional information for the API
            invocation, such as the request tracking id.
        broadened_query_jobs_count (int):
            If query broadening is enabled, we may append
            additional results from the broadened query.
            This number indicates how many of the jobs
            returned in the jobs field are from the
            broadened query. These results are always at the
            end of the jobs list. In particular, a value of
            0, or if the field isn't set, all the jobs in
            the jobs list are from the original (without
            broadening) query. If this field is non-zero,
            subsequent requests with offset after this
            result set should contain all broadened results.
        spell_correction (google.cloud.talent_v4beta1.types.SpellingCorrection):
            The spell checking result, and correction.
    """

    class MatchingJob(proto.Message):
        r"""Job entry with metadata inside
        [SearchJobsResponse][google.cloud.talent.v4beta1.SearchJobsResponse].

        Attributes:
            job (google.cloud.talent_v4beta1.types.Job):
                Job resource that matches the specified
                [SearchJobsRequest][google.cloud.talent.v4beta1.SearchJobsRequest].
            job_summary (str):
                A summary of the job with core information
                that's displayed on the search results listing
                page.
            job_title_snippet (str):
                Contains snippets of text from the
                [Job.title][google.cloud.talent.v4beta1.Job.title] field
                most closely matching a search query's keywords, if
                available. The matching query keywords are enclosed in HTML
                bold tags.
            search_text_snippet (str):
                Contains snippets of text from the
                [Job.description][google.cloud.talent.v4beta1.Job.description]
                and similar fields that most closely match a search query's
                keywords, if available. All HTML tags in the original fields
                are stripped when returned in this field, and matching query
                keywords are enclosed in HTML bold tags.
            commute_info (google.cloud.talent_v4beta1.types.SearchJobsResponse.CommuteInfo):
                Commute information which is generated based on specified
                [CommuteFilter][google.cloud.talent.v4beta1.CommuteFilter].
        """

        job: gct_job.Job = proto.Field(
            proto.MESSAGE,
            number=1,
            message=gct_job.Job,
        )
        job_summary: str = proto.Field(
            proto.STRING,
            number=2,
        )
        job_title_snippet: str = proto.Field(
            proto.STRING,
            number=3,
        )
        search_text_snippet: str = proto.Field(
            proto.STRING,
            number=4,
        )
        commute_info: "SearchJobsResponse.CommuteInfo" = proto.Field(
            proto.MESSAGE,
            number=5,
            message="SearchJobsResponse.CommuteInfo",
        )

    class CommuteInfo(proto.Message):
        r"""Commute details related to this job.

        Attributes:
            job_location (google.cloud.talent_v4beta1.types.Location):
                Location used as the destination in the
                commute calculation.
            travel_duration (google.protobuf.duration_pb2.Duration):
                The number of seconds required to travel to
                the job location from the query location. A
                duration of 0 seconds indicates that the job
                isn't reachable within the requested duration,
                but was returned as part of an expanded query.
        """

        job_location: common.Location = proto.Field(
            proto.MESSAGE,
            number=1,
            message=common.Location,
        )
        travel_duration: duration_pb2.Duration = proto.Field(
            proto.MESSAGE,
            number=2,
            message=duration_pb2.Duration,
        )

    @property
    def raw_page(self):
        return self

    matching_jobs: MutableSequence[MatchingJob] = proto.RepeatedField(
        proto.MESSAGE,
        number=1,
        message=MatchingJob,
    )
    histogram_query_results: MutableSequence[
        histogram.HistogramQueryResult
    ] = proto.RepeatedField(
        proto.MESSAGE,
        number=2,
        message=histogram.HistogramQueryResult,
    )
    next_page_token: str = proto.Field(
        proto.STRING,
        number=3,
    )
    location_filters: MutableSequence[common.Location] = proto.RepeatedField(
        proto.MESSAGE,
        number=4,
        message=common.Location,
    )
    estimated_total_size: int = proto.Field(
        proto.INT32,
        number=5,
    )
    total_size: int = proto.Field(
        proto.INT32,
        number=6,
    )
    metadata: common.ResponseMetadata = proto.Field(
        proto.MESSAGE,
        number=7,
        message=common.ResponseMetadata,
    )
    broadened_query_jobs_count: int = proto.Field(
        proto.INT32,
        number=8,
    )
    spell_correction: common.SpellingCorrection = proto.Field(
        proto.MESSAGE,
        number=9,
        message=common.SpellingCorrection,
    )


class BatchCreateJobsRequest(proto.Message):
    r"""Request to create a batch of jobs.

    Attributes:
        parent (str):
            Required. The resource name of the tenant under which the
            job is created.

            The format is "projects/{project_id}/tenants/{tenant_id}".
            For example, "projects/foo/tenant/bar". If tenant id is
            unspecified, a default tenant is created. For example,
            "projects/foo".
        jobs (MutableSequence[google.cloud.talent_v4beta1.types.Job]):
            Required. The jobs to be created.
    """

    parent: str = proto.Field(
        proto.STRING,
        number=1,
    )
    jobs: MutableSequence[gct_job.Job] = proto.RepeatedField(
        proto.MESSAGE,
        number=2,
        message=gct_job.Job,
    )


class BatchUpdateJobsRequest(proto.Message):
    r"""Request to update a batch of jobs.

    Attributes:
        parent (str):
            Required. The resource name of the tenant under which the
            job is created.

            The format is "projects/{project_id}/tenants/{tenant_id}".
            For example, "projects/foo/tenant/bar". If tenant id is
            unspecified, a default tenant is created. For example,
            "projects/foo".
        jobs (MutableSequence[google.cloud.talent_v4beta1.types.Job]):
            Required. The jobs to be updated.
        update_mask (google.protobuf.field_mask_pb2.FieldMask):
            Strongly recommended for the best service experience. Be
            aware that it will also increase latency when checking the
            status of a batch operation.

            If
            [update_mask][google.cloud.talent.v4beta1.BatchUpdateJobsRequest.update_mask]
            is provided, only the specified fields in
            [Job][google.cloud.talent.v4beta1.Job] are updated.
            Otherwise all the fields are updated.

            A field mask to restrict the fields that are updated. Only
            top level fields of [Job][google.cloud.talent.v4beta1.Job]
            are supported.

            If
            [update_mask][google.cloud.talent.v4beta1.BatchUpdateJobsRequest.update_mask]
            is provided, The [Job][google.cloud.talent.v4beta1.Job]
            inside
            [JobResult][google.cloud.talent.v4beta1.JobOperationResult.JobResult]
            will only contains fields that is updated, plus the Id of
            the Job. Otherwise, [Job][google.cloud.talent.v4beta1.Job]
            will include all fields, which can yield a very large
            response.
    """

    parent: str = proto.Field(
        proto.STRING,
        number=1,
    )
    jobs: MutableSequence[gct_job.Job] = proto.RepeatedField(
        proto.MESSAGE,
        number=2,
        message=gct_job.Job,
    )
    update_mask: field_mask_pb2.FieldMask = proto.Field(
        proto.MESSAGE,
        number=3,
        message=field_mask_pb2.FieldMask,
    )


class JobOperationResult(proto.Message):
    r"""The result of
    [JobService.BatchCreateJobs][google.cloud.talent.v4beta1.JobService.BatchCreateJobs]
    or
    [JobService.BatchUpdateJobs][google.cloud.talent.v4beta1.JobService.BatchUpdateJobs]
    APIs. It's used to replace
    [google.longrunning.Operation.response][google.longrunning.Operation.response]
    in case of success.

    Attributes:
        job_results (MutableSequence[google.cloud.talent_v4beta1.types.JobOperationResult.JobResult]):
            List of job mutation results from a batch
            mutate operation. It can change until operation
            status is FINISHED, FAILED or CANCELLED.
    """

    class JobResult(proto.Message):
        r"""Mutation result of a job.

        Attributes:
            job (google.cloud.talent_v4beta1.types.Job):
                Here [Job][google.cloud.talent.v4beta1.Job] only contains
                basic information including
                [name][google.cloud.talent.v4beta1.Job.name],
                [company][google.cloud.talent.v4beta1.Job.company],
                [language_code][google.cloud.talent.v4beta1.Job.language_code]
                and
                [requisition_id][google.cloud.talent.v4beta1.Job.requisition_id],
                use getJob method to retrieve detailed information of the
                created/updated job.
            status (google.rpc.status_pb2.Status):
                The status of the job processed. This field is populated if
                the processing of the
                [job][google.cloud.talent.v4beta1.JobOperationResult.JobResult.job]
                fails.
        """

        job: gct_job.Job = proto.Field(
            proto.MESSAGE,
            number=1,
            message=gct_job.Job,
        )
        status: status_pb2.Status = proto.Field(
            proto.MESSAGE,
            number=2,
            message=status_pb2.Status,
        )

    job_results: MutableSequence[JobResult] = proto.RepeatedField(
        proto.MESSAGE,
        number=1,
        message=JobResult,
    )


__all__ = tuple(sorted(__protobuf__.manifest))



# -*- coding: utf-8 -*-
# Copyright 2022 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
from typing import Callable, Dict, Optional, Sequence, Tuple, Union
import warnings

from google.api_core import gapic_v1, grpc_helpers, operations_v1
import google.auth  # type: ignore
from google.auth import credentials as ga_credentials  # type: ignore
from google.auth.transport.grpc import SslCredentials  # type: ignore
from google.longrunning import operations_pb2  # type: ignore
from google.protobuf import empty_pb2  # type: ignore
import grpc  # type: ignore

from google.cloud.talent_v4beta1.types import job
from google.cloud.talent_v4beta1.types import job as gct_job
from google.cloud.talent_v4beta1.types import job_service

from .base import DEFAULT_CLIENT_INFO, JobServiceTransport


class JobServiceGrpcTransport(JobServiceTransport):
    """gRPC backend transport for JobService.

    A service handles job management, including job CRUD,
    enumeration and search.

    This class defines the same methods as the primary client, so the
    primary client can load the underlying transport implementation
    and call it.

    It sends protocol buffers over the wire using gRPC (which is built on
    top of HTTP/2); the ``grpcio`` package must be installed.
    """

    _stubs: Dict[str, Callable]

    def __init__(
        self,
        *,
        host: str = "jobs.googleapis.com",
        credentials: Optional[ga_credentials.Credentials] = None,
        credentials_file: Optional[str] = None,
        scopes: Optional[Sequence[str]] = None,
        channel: Optional[grpc.Channel] = None,
        api_mtls_endpoint: Optional[str] = None,
        client_cert_source: Optional[Callable[[], Tuple[bytes, bytes]]] = None,
        ssl_channel_credentials: Optional[grpc.ChannelCredentials] = None,
        client_cert_source_for_mtls: Optional[Callable[[], Tuple[bytes, bytes]]] = None,
        quota_project_id: Optional[str] = None,
        client_info: gapic_v1.client_info.ClientInfo = DEFAULT_CLIENT_INFO,
        always_use_jwt_access: Optional[bool] = False,
        api_audience: Optional[str] = None,
    ) -> None:
        """Instantiate the transport.

        Args:
            host (Optional[str]):
                 The hostname to connect to.
            credentials (Optional[google.auth.credentials.Credentials]): The
                authorization credentials to attach to requests. These
                credentials identify the application to the service; if none
                are specified, the client will attempt to ascertain the
                credentials from the environment.
                This argument is ignored if ``channel`` is provided.
            credentials_file (Optional[str]): A file with credentials that can
                be loaded with :func:`google.auth.load_credentials_from_file`.
                This argument is ignored if ``channel`` is provided.
            scopes (Optional(Sequence[str])): A list of scopes. This argument is
                ignored if ``channel`` is provided.
            channel (Optional[grpc.Channel]): A ``Channel`` instance through
                which to make calls.
            api_mtls_endpoint (Optional[str]): Deprecated. The mutual TLS endpoint.
                If provided, it overrides the ``host`` argument and tries to create
                a mutual TLS channel with client SSL credentials from
                ``client_cert_source`` or application default SSL credentials.
            client_cert_source (Optional[Callable[[], Tuple[bytes, bytes]]]):
                Deprecated. A callback to provide client SSL certificate bytes and
                private key bytes, both in PEM format. It is ignored if
                ``api_mtls_endpoint`` is None.
            ssl_channel_credentials (grpc.ChannelCredentials): SSL credentials
                for the grpc channel. It is ignored if ``channel`` is provided.
            client_cert_source_for_mtls (Optional[Callable[[], Tuple[bytes, bytes]]]):
                A callback to provide client certificate bytes and private key bytes,
                both in PEM format. It is used to configure a mutual TLS channel. It is
                ignored if ``channel`` or ``ssl_channel_credentials`` is provided.
            quota_project_id (Optional[str]): An optional project to use for billing
                and quota.
            client_info (google.api_core.gapic_v1.client_info.ClientInfo):
                The client info used to send a user-agent string along with
                API requests. If ``None``, then default info will be used.
                Generally, you only need to set this if you're developing
                your own client library.
            always_use_jwt_access (Optional[bool]): Whether self signed JWT should
                be used for service account credentials.

        Raises:
          google.auth.exceptions.MutualTLSChannelError: If mutual TLS transport
              creation failed for any reason.
          google.api_core.exceptions.DuplicateCredentialArgs: If both ``credentials``
              and ``credentials_file`` are passed.
        """
        self._grpc_channel = None
        self._ssl_channel_credentials = ssl_channel_credentials
        self._stubs: Dict[str, Callable] = {}
        self._operations_client: Optional[operations_v1.OperationsClient] = None

        if api_mtls_endpoint:
            warnings.warn("api_mtls_endpoint is deprecated", DeprecationWarning)
        if client_cert_source:
            warnings.warn("client_cert_source is deprecated", DeprecationWarning)

        if channel:
            # Ignore credentials if a channel was passed.
            credentials = False
            # If a channel was explicitly provided, set it.
            self._grpc_channel = channel
            self._ssl_channel_credentials = None

        else:
            if api_mtls_endpoint:
                host = api_mtls_endpoint

                # Create SSL credentials with client_cert_source or application
                # default SSL credentials.
                if client_cert_source:
                    cert, key = client_cert_source()
                    self._ssl_channel_credentials = grpc.ssl_channel_credentials(
                        certificate_chain=cert, private_key=key
                    )
                else:
                    self._ssl_channel_credentials = SslCredentials().ssl_credentials

            else:
                if client_cert_source_for_mtls and not ssl_channel_credentials:
                    cert, key = client_cert_source_for_mtls()
                    self._ssl_channel_credentials = grpc.ssl_channel_credentials(
                        certificate_chain=cert, private_key=key
                    )

        # The base transport sets the host, credentials and scopes
        super().__init__(
            host=host,
            credentials=credentials,
            credentials_file=credentials_file,
            scopes=scopes,
            quota_project_id=quota_project_id,
            client_info=client_info,
            always_use_jwt_access=always_use_jwt_access,
            api_audience=api_audience,
        )

        if not self._grpc_channel:
            self._grpc_channel = type(self).create_channel(
                self._host,
                # use the credentials which are saved
                credentials=self._credentials,
                # Set ``credentials_file`` to ``None`` here as
                # the credentials that we saved earlier should be used.
                credentials_file=None,
                scopes=self._scopes,
                ssl_credentials=self._ssl_channel_credentials,
                quota_project_id=quota_project_id,
                options=[
                    ("grpc.max_send_message_length", -1),
                    ("grpc.max_receive_message_length", -1),
                ],
            )

        # Wrap messages. This must be done after self._grpc_channel exists
        self._prep_wrapped_messages(client_info)

    @classmethod
    def create_channel(
        cls,
        host: str = "jobs.googleapis.com",
        credentials: Optional[ga_credentials.Credentials] = None,
        credentials_file: Optional[str] = None,
        scopes: Optional[Sequence[str]] = None,
        quota_project_id: Optional[str] = None,
        **kwargs,
    ) -> grpc.Channel:
        """Create and return a gRPC channel object.
        Args:
            host (Optional[str]): The host for the channel to use.
            credentials (Optional[~.Credentials]): The
                authorization credentials to attach to requests. These
                credentials identify this application to the service. If
                none are specified, the client will attempt to ascertain
                the credentials from the environment.
            credentials_file (Optional[str]): A file with credentials that can
                be loaded with :func:`google.auth.load_credentials_from_file`.
                This argument is mutually exclusive with credentials.
            scopes (Optional[Sequence[str]]): A optional list of scopes needed for this
                service. These are only used when credentials are not specified and
                are passed to :func:`google.auth.default`.
            quota_project_id (Optional[str]): An optional project to use for billing
                and quota.
            kwargs (Optional[dict]): Keyword arguments, which are passed to the
                channel creation.
        Returns:
            grpc.Channel: A gRPC channel object.

        Raises:
            google.api_core.exceptions.DuplicateCredentialArgs: If both ``credentials``
              and ``credentials_file`` are passed.
        """

        return grpc_helpers.create_channel(
            host,
            credentials=credentials,
            credentials_file=credentials_file,
            quota_project_id=quota_project_id,
            default_scopes=cls.AUTH_SCOPES,
            scopes=scopes,
            default_host=cls.DEFAULT_HOST,
            **kwargs,
        )

    @property
    def grpc_channel(self) -> grpc.Channel:
        """Return the channel designed to connect to this service."""
        return self._grpc_channel

    @property
    def operations_client(self) -> operations_v1.OperationsClient:
        """Create the client designed to process long-running operations.

        This property caches on the instance; repeated calls return the same
        client.
        """
        # Quick check: Only create a new client if we do not already have one.
        if self._operations_client is None:
            self._operations_client = operations_v1.OperationsClient(self.grpc_channel)

        # Return the client from cache.
        return self._operations_client

    @property
    def create_job(self) -> Callable[[job_service.CreateJobRequest], gct_job.Job]:
        r"""Return a callable for the create job method over gRPC.

        Creates a new job.
        Typically, the job becomes searchable within 10 seconds,
        but it may take up to 5 minutes.

        Returns:
            Callable[[~.CreateJobRequest],
                    ~.Job]:
                A function that, when called, will call the underlying RPC
                on the server.
        """
        # Generate a "stub function" on-the-fly which will actually make
        # the request.
        # gRPC handles serialization and deserialization, so we just need
        # to pass in the functions for each.
        if "create_job" not in self._stubs:
            self._stubs["create_job"] = self.grpc_channel.unary_unary(
                "/google.cloud.talent.v4beta1.JobService/CreateJob",
                request_serializer=job_service.CreateJobRequest.serialize,
                response_deserializer=gct_job.Job.deserialize,
            )
        return self._stubs["create_job"]

    @property
    def batch_create_jobs(
        self,
    ) -> Callable[[job_service.BatchCreateJobsRequest], operations_pb2.Operation]:
        r"""Return a callable for the batch create jobs method over gRPC.

        Begins executing a batch create jobs operation.

        Returns:
            Callable[[~.BatchCreateJobsRequest],
                    ~.Operation]:
                A function that, when called, will call the underlying RPC
                on the server.
        """
        # Generate a "stub function" on-the-fly which will actually make
        # the request.
        # gRPC handles serialization and deserialization, so we just need
        # to pass in the functions for each.
        if "batch_create_jobs" not in self._stubs:
            self._stubs["batch_create_jobs"] = self.grpc_channel.unary_unary(
                "/google.cloud.talent.v4beta1.JobService/BatchCreateJobs",
                request_serializer=job_service.BatchCreateJobsRequest.serialize,
                response_deserializer=operations_pb2.Operation.FromString,
            )
        return self._stubs["batch_create_jobs"]

    @property
    def get_job(self) -> Callable[[job_service.GetJobRequest], job.Job]:
        r"""Return a callable for the get job method over gRPC.

        Retrieves the specified job, whose status is OPEN or
        recently EXPIRED within the last 90 days.

        Returns:
            Callable[[~.GetJobRequest],
                    ~.Job]:
                A function that, when called, will call the underlying RPC
                on the server.
        """
        # Generate a "stub function" on-the-fly which will actually make
        # the request.
        # gRPC handles serialization and deserialization, so we just need
        # to pass in the functions for each.
        if "get_job" not in self._stubs:
            self._stubs["get_job"] = self.grpc_channel.unary_unary(
                "/google.cloud.talent.v4beta1.JobService/GetJob",
                request_serializer=job_service.GetJobRequest.serialize,
                response_deserializer=job.Job.deserialize,
            )
        return self._stubs["get_job"]

    @property
    def update_job(self) -> Callable[[job_service.UpdateJobRequest], gct_job.Job]:
        r"""Return a callable for the update job method over gRPC.

        Updates specified job.
        Typically, updated contents become visible in search
        results within 10 seconds, but it may take up to 5
        minutes.

        Returns:
            Callable[[~.UpdateJobRequest],
                    ~.Job]:
                A function that, when called, will call the underlying RPC
                on the server.
        """
        # Generate a "stub function" on-the-fly which will actually make
        # the request.
        # gRPC handles serialization and deserialization, so we just need
        # to pass in the functions for each.
        if "update_job" not in self._stubs:
            self._stubs["update_job"] = self.grpc_channel.unary_unary(
                "/google.cloud.talent.v4beta1.JobService/UpdateJob",
                request_serializer=job_service.UpdateJobRequest.serialize,
                response_deserializer=gct_job.Job.deserialize,
            )
        return self._stubs["update_job"]

    @property
    def batch_update_jobs(
        self,
    ) -> Callable[[job_service.BatchUpdateJobsRequest], operations_pb2.Operation]:
        r"""Return a callable for the batch update jobs method over gRPC.

        Begins executing a batch update jobs operation.

        Returns:
            Callable[[~.BatchUpdateJobsRequest],
                    ~.Operation]:
                A function that, when called, will call the underlying RPC
                on the server.
        """
        # Generate a "stub function" on-the-fly which will actually make
        # the request.
        # gRPC handles serialization and deserialization, so we just need
        # to pass in the functions for each.
        if "batch_update_jobs" not in self._stubs:
            self._stubs["batch_update_jobs"] = self.grpc_channel.unary_unary(
                "/google.cloud.talent.v4beta1.JobService/BatchUpdateJobs",
                request_serializer=job_service.BatchUpdateJobsRequest.serialize,
                response_deserializer=operations_pb2.Operation.FromString,
            )
        return self._stubs["batch_update_jobs"]

    @property
    def delete_job(self) -> Callable[[job_service.DeleteJobRequest], empty_pb2.Empty]:
        r"""Return a callable for the delete job method over gRPC.

        Deletes the specified job.
        Typically, the job becomes unsearchable within 10
        seconds, but it may take up to 5 minutes.

        Returns:
            Callable[[~.DeleteJobRequest],
                    ~.Empty]:
                A function that, when called, will call the underlying RPC
                on the server.
        """
        # Generate a "stub function" on-the-fly which will actually make
        # the request.
        # gRPC handles serialization and deserialization, so we just need
        # to pass in the functions for each.
        if "delete_job" not in self._stubs:
            self._stubs["delete_job"] = self.grpc_channel.unary_unary(
                "/google.cloud.talent.v4beta1.JobService/DeleteJob",
                request_serializer=job_service.DeleteJobRequest.serialize,
                response_deserializer=empty_pb2.Empty.FromString,
            )
        return self._stubs["delete_job"]

    @property
    def batch_delete_jobs(
        self,
    ) -> Callable[[job_service.BatchDeleteJobsRequest], empty_pb2.Empty]:
        r"""Return a callable for the batch delete jobs method over gRPC.

        Deletes a list of [Job][google.cloud.talent.v4beta1.Job]s by
        filter.

        Returns:
            Callable[[~.BatchDeleteJobsRequest],
                    ~.Empty]:
                A function that, when called, will call the underlying RPC
                on the server.
        """
        # Generate a "stub function" on-the-fly which will actually make
        # the request.
        # gRPC handles serialization and deserialization, so we just need
        # to pass in the functions for each.
        if "batch_delete_jobs" not in self._stubs:
            self._stubs["batch_delete_jobs"] = self.grpc_channel.unary_unary(
                "/google.cloud.talent.v4beta1.JobService/BatchDeleteJobs",
                request_serializer=job_service.BatchDeleteJobsRequest.serialize,
                response_deserializer=empty_pb2.Empty.FromString,
            )
        return self._stubs["batch_delete_jobs"]

    @property
    def list_jobs(
        self,
    ) -> Callable[[job_service.ListJobsRequest], job_service.ListJobsResponse]:
        r"""Return a callable for the list jobs method over gRPC.

        Lists jobs by filter.

        Returns:
            Callable[[~.ListJobsRequest],
                    ~.ListJobsResponse]:
                A function that, when called, will call the underlying RPC
                on the server.
        """
        # Generate a "stub function" on-the-fly which will actually make
        # the request.
        # gRPC handles serialization and deserialization, so we just need
        # to pass in the functions for each.
        if "list_jobs" not in self._stubs:
            self._stubs["list_jobs"] = self.grpc_channel.unary_unary(
                "/google.cloud.talent.v4beta1.JobService/ListJobs",
                request_serializer=job_service.ListJobsRequest.serialize,
                response_deserializer=job_service.ListJobsResponse.deserialize,
            )
        return self._stubs["list_jobs"]

    @property
    def search_jobs(
        self,
    ) -> Callable[[job_service.SearchJobsRequest], job_service.SearchJobsResponse]:
        r"""Return a callable for the search jobs method over gRPC.

        Searches for jobs using the provided
        [SearchJobsRequest][google.cloud.talent.v4beta1.SearchJobsRequest].

        This call constrains the
        [visibility][google.cloud.talent.v4beta1.Job.visibility] of jobs
        present in the database, and only returns jobs that the caller
        has permission to search against.

        Returns:
            Callable[[~.SearchJobsRequest],
                    ~.SearchJobsResponse]:
                A function that, when called, will call the underlying RPC
                on the server.
        """
        # Generate a "stub function" on-the-fly which will actually make
        # the request.
        # gRPC handles serialization and deserialization, so we just need
        # to pass in the functions for each.
        if "search_jobs" not in self._stubs:
            self._stubs["search_jobs"] = self.grpc_channel.unary_unary(
                "/google.cloud.talent.v4beta1.JobService/SearchJobs",
                request_serializer=job_service.SearchJobsRequest.serialize,
                response_deserializer=job_service.SearchJobsResponse.deserialize,
            )
        return self._stubs["search_jobs"]

    @property
    def search_jobs_for_alert(
        self,
    ) -> Callable[[job_service.SearchJobsRequest], job_service.SearchJobsResponse]:
        r"""Return a callable for the search jobs for alert method over gRPC.

        Searches for jobs using the provided
        [SearchJobsRequest][google.cloud.talent.v4beta1.SearchJobsRequest].

        This API call is intended for the use case of targeting passive
        job seekers (for example, job seekers who have signed up to
        receive email alerts about potential job opportunities), and has
        different algorithmic adjustments that are targeted to passive
        job seekers.

        This call constrains the
        [visibility][google.cloud.talent.v4beta1.Job.visibility] of jobs
        present in the database, and only returns jobs the caller has
        permission to search against.

        Returns:
            Callable[[~.SearchJobsRequest],
                    ~.SearchJobsResponse]:
                A function that, when called, will call the underlying RPC
                on the server.
        """
        # Generate a "stub function" on-the-fly which will actually make
        # the request.
        # gRPC handles serialization and deserialization, so we just need
        # to pass in the functions for each.
        if "search_jobs_for_alert" not in self._stubs:
            self._stubs["search_jobs_for_alert"] = self.grpc_channel.unary_unary(
                "/google.cloud.talent.v4beta1.JobService/SearchJobsForAlert",
                request_serializer=job_service.SearchJobsRequest.serialize,
                response_deserializer=job_service.SearchJobsResponse.deserialize,
            )
        return self._stubs["search_jobs_for_alert"]

    def close(self):
        self.grpc_channel.close()

    @property
    def get_operation(
        self,
    ) -> Callable[[operations_pb2.GetOperationRequest], operations_pb2.Operation]:
        r"""Return a callable for the get_operation method over gRPC."""
        # Generate a "stub function" on-the-fly which will actually make
        # the request.
        # gRPC handles serialization and deserialization, so we just need
        # to pass in the functions for each.
        if "get_operation" not in self._stubs:
            self._stubs["get_operation"] = self.grpc_channel.unary_unary(
                "/google.longrunning.Operations/GetOperation",
                request_serializer=operations_pb2.GetOperationRequest.SerializeToString,
                response_deserializer=operations_pb2.Operation.FromString,
            )
        return self._stubs["get_operation"]

    @property
    def kind(self) -> str:
        return "grpc"


__all__ = ("JobServiceGrpcTransport",)



# -*- coding: utf-8 -*-
# Copyright 2022 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
from typing import MutableMapping, MutableSequence

from google.protobuf import duration_pb2  # type: ignore
from google.type import latlng_pb2  # type: ignore
from google.type import timeofday_pb2  # type: ignore
import proto  # type: ignore

from google.cloud.talent_v4.types import common

__protobuf__ = proto.module(
    package="google.cloud.talent.v4",
    manifest={
        "JobQuery",
        "LocationFilter",
        "CompensationFilter",
        "CommuteFilter",
    },
)


class JobQuery(proto.Message):
    r"""The query required to perform a search query.

    Attributes:
        query (str):
            The query string that matches against the job
            title, description, and location fields.

            The maximum number of allowed characters is 255.
        query_language_code (str):
            The language code of
            [query][google.cloud.talent.v4.JobQuery.query]. For example,
            "en-US". This field helps to better interpret the query.

            If a value isn't specified, the query language code is
            automatically detected, which may not be accurate.

            Language code should be in BCP-47 format, such as "en-US" or
            "sr-Latn". For more information, see `Tags for Identifying
            Languages <https://tools.ietf.org/html/bcp47>`__.
        companies (MutableSequence[str]):
            This filter specifies the company entities to search
            against.

            If a value isn't specified, jobs are searched for against
            all companies.

            If multiple values are specified, jobs are searched against
            the companies specified.

            The format is
            "projects/{project_id}/tenants/{tenant_id}/companies/{company_id}".
            For example, "projects/foo/tenants/bar/companies/baz".

            At most 20 company filters are allowed.
        location_filters (MutableSequence[google.cloud.talent_v4.types.LocationFilter]):
            The location filter specifies geo-regions containing the
            jobs to search against. See
            [LocationFilter][google.cloud.talent.v4.LocationFilter] for
            more information.

            If a location value isn't specified, jobs fitting the other
            search criteria are retrieved regardless of where they're
            located.

            If multiple values are specified, jobs are retrieved from
            any of the specified locations. If different values are
            specified for the
            [LocationFilter.distance_in_miles][google.cloud.talent.v4.LocationFilter.distance_in_miles]
            parameter, the maximum provided distance is used for all
            locations.

            At most 5 location filters are allowed.
        job_categories (MutableSequence[google.cloud.talent_v4.types.JobCategory]):
            The category filter specifies the categories of jobs to
            search against. See
            [JobCategory][google.cloud.talent.v4.JobCategory] for more
            information.

            If a value isn't specified, jobs from any category are
            searched against.

            If multiple values are specified, jobs from any of the
            specified categories are searched against.
        commute_filter (google.cloud.talent_v4.types.CommuteFilter):
            Allows filtering jobs by commute time with different travel
            methods (for example, driving or public transit).

            Note: This only works when you specify a
            [CommuteMethod][google.cloud.talent.v4.CommuteMethod]. In
            this case,
            [location_filters][google.cloud.talent.v4.JobQuery.location_filters]
            is ignored.

            Currently we don't support sorting by commute time.
        company_display_names (MutableSequence[str]):
            This filter specifies the company
            [Company.display_name][google.cloud.talent.v4.Company.display_name]
            of the jobs to search against. The company name must match
            the value exactly.

            Alternatively, the value being searched for can be wrapped
            in different match operators. ``SUBSTRING_MATCH([value])``
            The company name must contain a case insensitive substring
            match of the value. Using this function may increase
            latency.

            Sample Value: ``SUBSTRING_MATCH(google)``

            ``MULTI_WORD_TOKEN_MATCH([value])`` The value will be
            treated as a multi word token and the company name must
            contain a case insensitive match of the value. Using this
            function may increase latency.

            Sample Value: ``MULTI_WORD_TOKEN_MATCH(google)``

            If a value isn't specified, jobs within the search results
            are associated with any company.

            If multiple values are specified, jobs within the search
            results may be associated with any of the specified
            companies.

            At most 20 company display name filters are allowed.
        compensation_filter (google.cloud.talent_v4.types.CompensationFilter):
            This search filter is applied only to
            [Job.compensation_info][google.cloud.talent.v4.Job.compensation_info].
            For example, if the filter is specified as "Hourly job with
            per-hour compensation > $15", only jobs meeting these
            criteria are searched. If a filter isn't defined, all open
            jobs are searched.
        custom_attribute_filter (str):
            This filter specifies a structured syntax to match against
            the
            [Job.custom_attributes][google.cloud.talent.v4.Job.custom_attributes]
            marked as ``filterable``.

            The syntax for this expression is a subset of SQL syntax.

            Supported operators are: ``=``, ``!=``, ``<``, ``<=``,
            ``>``, and ``>=`` where the left of the operator is a custom
            field key and the right of the operator is a number or a
            quoted string. You must escape backslash (\) and quote (")
            characters.

            Supported functions are ``LOWER([field_name])`` to perform a
            case insensitive match and ``EMPTY([field_name])`` to filter
            on the existence of a key.

            Boolean expressions (AND/OR/NOT) are supported up to 3
            levels of nesting (for example, "((A AND B AND C) OR NOT D)
            AND E"), a maximum of 100 comparisons or functions are
            allowed in the expression. The expression must be < 10000
            bytes in length.

            Sample Query:
            ``(LOWER(driving_license)="class \"a\"" OR EMPTY(driving_license)) AND driving_years > 10``
        disable_spell_check (bool):
            This flag controls the spell-check feature.
            If false, the service attempts to correct a
            misspelled query, for example, "enginee" is
            corrected to "engineer".
            Defaults to false: a spell check is performed.
        employment_types (MutableSequence[google.cloud.talent_v4.types.EmploymentType]):
            The employment type filter specifies the employment type of
            jobs to search against, such as
            [EmploymentType.FULL_TIME][google.cloud.talent.v4.EmploymentType.FULL_TIME].

            If a value isn't specified, jobs in the search results
            includes any employment type.

            If multiple values are specified, jobs in the search results
            include any of the specified employment types.
        language_codes (MutableSequence[str]):
            This filter specifies the locale of jobs to search against,
            for example, "en-US".

            If a value isn't specified, the search results can contain
            jobs in any locale.

            Language codes should be in BCP-47 format, such as "en-US"
            or "sr-Latn". For more information, see `Tags for
            Identifying
            Languages <https://tools.ietf.org/html/bcp47>`__.

            At most 10 language code filters are allowed.
        publish_time_range (google.cloud.talent_v4.types.TimestampRange):
            Jobs published within a range specified by
            this filter are searched against.
        excluded_jobs (MutableSequence[str]):
            This filter specifies a list of job names to
            be excluded during search.
            At most 400 excluded job names are allowed.
    """

    query: str = proto.Field(
        proto.STRING,
        number=1,
    )
    query_language_code: str = proto.Field(
        proto.STRING,
        number=14,
    )
    companies: MutableSequence[str] = proto.RepeatedField(
        proto.STRING,
        number=2,
    )
    location_filters: MutableSequence["LocationFilter"] = proto.RepeatedField(
        proto.MESSAGE,
        number=3,
        message="LocationFilter",
    )
    job_categories: MutableSequence[common.JobCategory] = proto.RepeatedField(
        proto.ENUM,
        number=4,
        enum=common.JobCategory,
    )
    commute_filter: "CommuteFilter" = proto.Field(
        proto.MESSAGE,
        number=5,
        message="CommuteFilter",
    )
    company_display_names: MutableSequence[str] = proto.RepeatedField(
        proto.STRING,
        number=6,
    )
    compensation_filter: "CompensationFilter" = proto.Field(
        proto.MESSAGE,
        number=7,
        message="CompensationFilter",
    )
    custom_attribute_filter: str = proto.Field(
        proto.STRING,
        number=8,
    )
    disable_spell_check: bool = proto.Field(
        proto.BOOL,
        number=9,
    )
    employment_types: MutableSequence[common.EmploymentType] = proto.RepeatedField(
        proto.ENUM,
        number=10,
        enum=common.EmploymentType,
    )
    language_codes: MutableSequence[str] = proto.RepeatedField(
        proto.STRING,
        number=11,
    )
    publish_time_range: common.TimestampRange = proto.Field(
        proto.MESSAGE,
        number=12,
        message=common.TimestampRange,
    )
    excluded_jobs: MutableSequence[str] = proto.RepeatedField(
        proto.STRING,
        number=13,
    )


class LocationFilter(proto.Message):
    r"""Geographic region of the search.

    Attributes:
        address (str):
            The address name, such as "Mountain View" or
            "Bay Area".
        region_code (str):
            CLDR region code of the country/region. This field may be
            used in two ways:

            1) If telecommute preference is not set, this field is used
               address ambiguity of the user-input address. For example,
               "Liverpool" may refer to "Liverpool, NY, US" or
               "Liverpool, UK". This region code biases the address
               resolution toward a specific country or territory. If
               this field is not set, address resolution is biased
               toward the United States by default.

            2) If telecommute preference is set to TELECOMMUTE_ALLOWED,
               the telecommute location filter will be limited to the
               region specified in this field. If this field is not set,
               the telecommute job locations will not be

            See
            https://unicode-org.github.io/cldr-staging/charts/latest/supplemental/territory_information.html
            for details. Example: "CH" for Switzerland.
        lat_lng (google.type.latlng_pb2.LatLng):
            The latitude and longitude of the geographic center to
            search from. This field is ignored if ``address`` is
            provided.
        distance_in_miles (float):
            The distance_in_miles is applied when the location being
            searched for is identified as a city or smaller. This field
            is ignored if the location being searched for is a state or
            larger.
        telecommute_preference (google.cloud.talent_v4.types.LocationFilter.TelecommutePreference):
            Allows the client to return jobs without a set location,
            specifically, telecommuting jobs (telecommuting is
            considered by the service as a special location).
            [Job.posting_region][google.cloud.talent.v4.Job.posting_region]
            indicates if a job permits telecommuting. If this field is
            set to
            [TelecommutePreference.TELECOMMUTE_ALLOWED][google.cloud.talent.v4.LocationFilter.TelecommutePreference.TELECOMMUTE_ALLOWED],
            telecommuting jobs are searched, and
            [address][google.cloud.talent.v4.LocationFilter.address] and
            [lat_lng][google.cloud.talent.v4.LocationFilter.lat_lng] are
            ignored. If not set or set to
            [TelecommutePreference.TELECOMMUTE_EXCLUDED][google.cloud.talent.v4.LocationFilter.TelecommutePreference.TELECOMMUTE_EXCLUDED],
            the telecommute status of the jobs is ignored. Jobs that
            have
            [PostingRegion.TELECOMMUTE][google.cloud.talent.v4.PostingRegion.TELECOMMUTE]
            and have additional
            [Job.addresses][google.cloud.talent.v4.Job.addresses] may
            still be matched based on other location filters using
            [address][google.cloud.talent.v4.LocationFilter.address] or
            [latlng][].

            This filter can be used by itself to search exclusively for
            telecommuting jobs, or it can be combined with another
            location filter to search for a combination of job
            locations, such as "Mountain View" or "telecommuting" jobs.
            However, when used in combination with other location
            filters, telecommuting jobs can be treated as less relevant
            than other jobs in the search response.

            This field is only used for job search requests.
    """

    class TelecommutePreference(proto.Enum):
        r"""Specify whether to include telecommute jobs."""
        TELECOMMUTE_PREFERENCE_UNSPECIFIED = 0
        TELECOMMUTE_EXCLUDED = 1
        TELECOMMUTE_ALLOWED = 2
        TELECOMMUTE_JOBS_EXCLUDED = 3

    address: str = proto.Field(
        proto.STRING,
        number=1,
    )
    region_code: str = proto.Field(
        proto.STRING,
        number=2,
    )
    lat_lng: latlng_pb2.LatLng = proto.Field(
        proto.MESSAGE,
        number=3,
        message=latlng_pb2.LatLng,
    )
    distance_in_miles: float = proto.Field(
        proto.DOUBLE,
        number=4,
    )
    telecommute_preference: TelecommutePreference = proto.Field(
        proto.ENUM,
        number=5,
        enum=TelecommutePreference,
    )


class CompensationFilter(proto.Message):
    r"""Filter on job compensation type and amount.

    Attributes:
        type_ (google.cloud.talent_v4.types.CompensationFilter.FilterType):
            Required. Type of filter.
        units (MutableSequence[google.cloud.talent_v4.types.CompensationInfo.CompensationUnit]):
            Required. Specify desired ``base compensation entry's``
            [CompensationInfo.CompensationUnit][google.cloud.talent.v4.CompensationInfo.CompensationUnit].
        range_ (google.cloud.talent_v4.types.CompensationInfo.CompensationRange):
            Compensation range.
        include_jobs_with_unspecified_compensation_range (bool):
            If set to true, jobs with unspecified
            compensation range fields are included.
    """

    class FilterType(proto.Enum):
        r"""Specify the type of filtering."""
        FILTER_TYPE_UNSPECIFIED = 0
        UNIT_ONLY = 1
        UNIT_AND_AMOUNT = 2
        ANNUALIZED_BASE_AMOUNT = 3
        ANNUALIZED_TOTAL_AMOUNT = 4

    type_: FilterType = proto.Field(
        proto.ENUM,
        number=1,
        enum=FilterType,
    )
    units: MutableSequence[
        common.CompensationInfo.CompensationUnit
    ] = proto.RepeatedField(
        proto.ENUM,
        number=2,
        enum=common.CompensationInfo.CompensationUnit,
    )
    range_: common.CompensationInfo.CompensationRange = proto.Field(
        proto.MESSAGE,
        number=3,
        message=common.CompensationInfo.CompensationRange,
    )
    include_jobs_with_unspecified_compensation_range: bool = proto.Field(
        proto.BOOL,
        number=4,
    )


class CommuteFilter(proto.Message):
    r"""Parameters needed for commute search.

    This message has `oneof`_ fields (mutually exclusive fields).
    For each oneof, at most one member field can be set at the same time.
    Setting any member of the oneof automatically clears all other
    members.

    .. _oneof: https://proto-plus-python.readthedocs.io/en/stable/fields.html#oneofs-mutually-exclusive-fields

    Attributes:
        commute_method (google.cloud.talent_v4.types.CommuteMethod):
            Required. The method of transportation to
            calculate the commute time for.
        start_coordinates (google.type.latlng_pb2.LatLng):
            Required. The latitude and longitude of the
            location to calculate the commute time from.
        travel_duration (google.protobuf.duration_pb2.Duration):
            Required. The maximum travel time in seconds. The maximum
            allowed value is ``3600s`` (one hour). Format is ``123s``.
        allow_imprecise_addresses (bool):
            If ``true``, jobs without street level addresses may also be
            returned. For city level addresses, the city center is used.
            For state and coarser level addresses, text matching is
            used. If this field is set to ``false`` or isn't specified,
            only jobs that include street level addresses will be
            returned by commute search.
        road_traffic (google.cloud.talent_v4.types.CommuteFilter.RoadTraffic):
            Specifies the traffic density to use when
            calculating commute time.

            This field is a member of `oneof`_ ``traffic_option``.
        departure_time (google.type.timeofday_pb2.TimeOfDay):
            The departure time used to calculate traffic impact,
            represented as
            [google.type.TimeOfDay][google.type.TimeOfDay] in local time
            zone.

            Currently traffic model is restricted to hour level
            resolution.

            This field is a member of `oneof`_ ``traffic_option``.
    """

    class RoadTraffic(proto.Enum):
        r"""The traffic density to use when calculating commute time."""
        ROAD_TRAFFIC_UNSPECIFIED = 0
        TRAFFIC_FREE = 1
        BUSY_HOUR = 2

    commute_method: common.CommuteMethod = proto.Field(
        proto.ENUM,
        number=1,
        enum=common.CommuteMethod,
    )
    start_coordinates: latlng_pb2.LatLng = proto.Field(
        proto.MESSAGE,
        number=2,
        message=latlng_pb2.LatLng,
    )
    travel_duration: duration_pb2.Duration = proto.Field(
        proto.MESSAGE,
        number=3,
        message=duration_pb2.Duration,
    )
    allow_imprecise_addresses: bool = proto.Field(
        proto.BOOL,
        number=4,
    )
    road_traffic: RoadTraffic = proto.Field(
        proto.ENUM,
        number=5,
        oneof="traffic_option",
        enum=RoadTraffic,
    )
    departure_time: timeofday_pb2.TimeOfDay = proto.Field(
        proto.MESSAGE,
        number=6,
        oneof="traffic_option",
        message=timeofday_pb2.TimeOfDay,
    )


__all__ = tuple(sorted(__protobuf__.manifest))



# -*- coding: utf-8 -*-
# Copyright 2022 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
from typing import MutableMapping, MutableSequence

from google.protobuf import field_mask_pb2  # type: ignore
import proto  # type: ignore

from google.cloud.talent_v4.types import common
from google.cloud.talent_v4.types import company as gct_company

__protobuf__ = proto.module(
    package="google.cloud.talent.v4",
    manifest={
        "CreateCompanyRequest",
        "GetCompanyRequest",
        "UpdateCompanyRequest",
        "DeleteCompanyRequest",
        "ListCompaniesRequest",
        "ListCompaniesResponse",
    },
)


class CreateCompanyRequest(proto.Message):
    r"""The Request of the CreateCompany method.

    Attributes:
        parent (str):
            Required. Resource name of the tenant under which the
            company is created.

            The format is "projects/{project_id}/tenants/{tenant_id}",
            for example, "projects/foo/tenants/bar".
        company (google.cloud.talent_v4.types.Company):
            Required. The company to be created.
    """

    parent: str = proto.Field(
        proto.STRING,
        number=1,
    )
    company: gct_company.Company = proto.Field(
        proto.MESSAGE,
        number=2,
        message=gct_company.Company,
    )


class GetCompanyRequest(proto.Message):
    r"""Request for getting a company by name.

    Attributes:
        name (str):
            Required. The resource name of the company to be retrieved.

            The format is
            "projects/{project_id}/tenants/{tenant_id}/companies/{company_id}",
            for example,
            "projects/api-test-project/tenants/foo/companies/bar".
    """

    name: str = proto.Field(
        proto.STRING,
        number=1,
    )


class UpdateCompanyRequest(proto.Message):
    r"""Request for updating a specified company.

    Attributes:
        company (google.cloud.talent_v4.types.Company):
            Required. The company resource to replace the
            current resource in the system.
        update_mask (google.protobuf.field_mask_pb2.FieldMask):
            Strongly recommended for the best service experience.

            If
            [update_mask][google.cloud.talent.v4.UpdateCompanyRequest.update_mask]
            is provided, only the specified fields in
            [company][google.cloud.talent.v4.UpdateCompanyRequest.company]
            are updated. Otherwise all the fields are updated.

            A field mask to specify the company fields to be updated.
            Only top level fields of
            [Company][google.cloud.talent.v4.Company] are supported.
    """

    company: gct_company.Company = proto.Field(
        proto.MESSAGE,
        number=1,
        message=gct_company.Company,
    )
    update_mask: field_mask_pb2.FieldMask = proto.Field(
        proto.MESSAGE,
        number=2,
        message=field_mask_pb2.FieldMask,
    )


class DeleteCompanyRequest(proto.Message):
    r"""Request to delete a company.

    Attributes:
        name (str):
            Required. The resource name of the company to be deleted.

            The format is
            "projects/{project_id}/tenants/{tenant_id}/companies/{company_id}",
            for example, "projects/foo/tenants/bar/companies/baz".
    """

    name: str = proto.Field(
        proto.STRING,
        number=1,
    )


class ListCompaniesRequest(proto.Message):
    r"""List companies for which the client has ACL visibility.

    Attributes:
        parent (str):
            Required. Resource name of the tenant under which the
            company is created.

            The format is "projects/{project_id}/tenants/{tenant_id}",
            for example, "projects/foo/tenants/bar".
        page_token (str):
            The starting indicator from which to return
            results.
        page_size (int):
            The maximum number of companies to be
            returned, at most 100. Default is 100 if a
            non-positive number is provided.
        require_open_jobs (bool):
            Set to true if the companies requested must have open jobs.

            Defaults to false.

            If true, at most
            [page_size][google.cloud.talent.v4.ListCompaniesRequest.page_size]
            of companies are fetched, among which only those with open
            jobs are returned.
    """

    parent: str = proto.Field(
        proto.STRING,
        number=1,
    )
    page_token: str = proto.Field(
        proto.STRING,
        number=2,
    )
    page_size: int = proto.Field(
        proto.INT32,
        number=3,
    )
    require_open_jobs: bool = proto.Field(
        proto.BOOL,
        number=4,
    )


class ListCompaniesResponse(proto.Message):
    r"""The List companies response object.

    Attributes:
        companies (MutableSequence[google.cloud.talent_v4.types.Company]):
            Companies for the current client.
        next_page_token (str):
            A token to retrieve the next page of results.
        metadata (google.cloud.talent_v4.types.ResponseMetadata):
            Additional information for the API
            invocation, such as the request tracking id.
    """

    @property
    def raw_page(self):
        return self

    companies: MutableSequence[gct_company.Company] = proto.RepeatedField(
        proto.MESSAGE,
        number=1,
        message=gct_company.Company,
    )
    next_page_token: str = proto.Field(
        proto.STRING,
        number=2,
    )
    metadata: common.ResponseMetadata = proto.Field(
        proto.MESSAGE,
        number=3,
        message=common.ResponseMetadata,
    )


__all__ = tuple(sorted(__protobuf__.manifest))



# -*- coding: utf-8 -*-
# Copyright 2022 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
from .common import (
    BatchOperationMetadata,
    CommuteMethod,
    CompanySize,
    CompensationInfo,
    CustomAttribute,
    DegreeType,
    DeviceInfo,
    EmploymentType,
    HtmlSanitization,
    JobBenefit,
    JobCategory,
    JobLevel,
    Location,
    PostingRegion,
    RequestMetadata,
    ResponseMetadata,
    SpellingCorrection,
    TimestampRange,
    Visibility,
)
from .company import Company
from .company_service import (
    CreateCompanyRequest,
    DeleteCompanyRequest,
    GetCompanyRequest,
    ListCompaniesRequest,
    ListCompaniesResponse,
    UpdateCompanyRequest,
)
from .completion_service import CompleteQueryRequest, CompleteQueryResponse
from .event import ClientEvent, JobEvent
from .event_service import CreateClientEventRequest
from .filters import CommuteFilter, CompensationFilter, JobQuery, LocationFilter
from .histogram import HistogramQuery, HistogramQueryResult
from .job import Job
from .job_service import (
    BatchCreateJobsRequest,
    BatchDeleteJobsRequest,
    BatchUpdateJobsRequest,
    CreateJobRequest,
    DeleteJobRequest,
    GetJobRequest,
    JobOperationResult,
    JobView,
    ListJobsRequest,
    ListJobsResponse,
    SearchJobsRequest,
    SearchJobsResponse,
    UpdateJobRequest,
)
from .tenant import Tenant
from .tenant_service import (
    CreateTenantRequest,
    DeleteTenantRequest,
    GetTenantRequest,
    ListTenantsRequest,
    ListTenantsResponse,
    UpdateTenantRequest,
)

__all__ = (
    "BatchOperationMetadata",
    "CompensationInfo",
    "CustomAttribute",
    "DeviceInfo",
    "Location",
    "RequestMetadata",
    "ResponseMetadata",
    "SpellingCorrection",
    "TimestampRange",
    "CommuteMethod",
    "CompanySize",
    "DegreeType",
    "EmploymentType",
    "HtmlSanitization",
    "JobBenefit",
    "JobCategory",
    "JobLevel",
    "PostingRegion",
    "Visibility",
    "Company",
    "CreateCompanyRequest",
    "DeleteCompanyRequest",
    "GetCompanyRequest",
    "ListCompaniesRequest",
    "ListCompaniesResponse",
    "UpdateCompanyRequest",
    "CompleteQueryRequest",
    "CompleteQueryResponse",
    "ClientEvent",
    "JobEvent",
    "CreateClientEventRequest",
    "CommuteFilter",
    "CompensationFilter",
    "JobQuery",
    "LocationFilter",
    "HistogramQuery",
    "HistogramQueryResult",
    "Job",
    "BatchCreateJobsRequest",
    "BatchDeleteJobsRequest",
    "BatchUpdateJobsRequest",
    "CreateJobRequest",
    "DeleteJobRequest",
    "GetJobRequest",
    "JobOperationResult",
    "ListJobsRequest",
    "ListJobsResponse",
    "SearchJobsRequest",
    "SearchJobsResponse",
    "UpdateJobRequest",
    "JobView",
    "Tenant",
    "CreateTenantRequest",
    "DeleteTenantRequest",
    "GetTenantRequest",
    "ListTenantsRequest",
    "ListTenantsResponse",
    "UpdateTenantRequest",
)



# -*- coding: utf-8 -*-
# Copyright 2022 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
from typing import MutableMapping, MutableSequence

import proto  # type: ignore

from google.cloud.talent_v4.types import common

__protobuf__ = proto.module(
    package="google.cloud.talent.v4",
    manifest={
        "CompleteQueryRequest",
        "CompleteQueryResponse",
    },
)


class CompleteQueryRequest(proto.Message):
    r"""Auto-complete parameters.

    Attributes:
        tenant (str):
            Required. Resource name of tenant the completion is
            performed within.

            The format is "projects/{project_id}/tenants/{tenant_id}",
            for example, "projects/foo/tenants/bar".
        query (str):
            Required. The query used to generate
            suggestions.
            The maximum number of allowed characters is 255.
        language_codes (MutableSequence[str]):
            The list of languages of the query. This is the BCP-47
            language code, such as "en-US" or "sr-Latn". For more
            information, see `Tags for Identifying
            Languages <https://tools.ietf.org/html/bcp47>`__.

            The maximum number of allowed characters is 255.
        page_size (int):
            Required. Completion result count.
            The maximum allowed page size is 10.
        company (str):
            If provided, restricts completion to specified company.

            The format is
            "projects/{project_id}/tenants/{tenant_id}/companies/{company_id}",
            for example, "projects/foo/tenants/bar/companies/baz".
        scope (google.cloud.talent_v4.types.CompleteQueryRequest.CompletionScope):
            The scope of the completion. The defaults is
            [CompletionScope.PUBLIC][google.cloud.talent.v4.CompleteQueryRequest.CompletionScope.PUBLIC].
        type_ (google.cloud.talent_v4.types.CompleteQueryRequest.CompletionType):
            The completion topic. The default is
            [CompletionType.COMBINED][google.cloud.talent.v4.CompleteQueryRequest.CompletionType.COMBINED].
    """

    class CompletionScope(proto.Enum):
        r"""Enum to specify the scope of completion."""
        COMPLETION_SCOPE_UNSPECIFIED = 0
        TENANT = 1
        PUBLIC = 2

    class CompletionType(proto.Enum):
        r"""Enum to specify auto-completion topics."""
        COMPLETION_TYPE_UNSPECIFIED = 0
        JOB_TITLE = 1
        COMPANY_NAME = 2
        COMBINED = 3

    tenant: str = proto.Field(
        proto.STRING,
        number=1,
    )
    query: str = proto.Field(
        proto.STRING,
        number=2,
    )
    language_codes: MutableSequence[str] = proto.RepeatedField(
        proto.STRING,
        number=3,
    )
    page_size: int = proto.Field(
        proto.INT32,
        number=4,
    )
    company: str = proto.Field(
        proto.STRING,
        number=5,
    )
    scope: CompletionScope = proto.Field(
        proto.ENUM,
        number=6,
        enum=CompletionScope,
    )
    type_: CompletionType = proto.Field(
        proto.ENUM,
        number=7,
        enum=CompletionType,
    )


class CompleteQueryResponse(proto.Message):
    r"""Response of auto-complete query.

    Attributes:
        completion_results (MutableSequence[google.cloud.talent_v4.types.CompleteQueryResponse.CompletionResult]):
            Results of the matching job/company
            candidates.
        metadata (google.cloud.talent_v4.types.ResponseMetadata):
            Additional information for the API
            invocation, such as the request tracking id.
    """

    class CompletionResult(proto.Message):
        r"""Resource that represents completion results.

        Attributes:
            suggestion (str):
                The suggestion for the query.
            type_ (google.cloud.talent_v4.types.CompleteQueryRequest.CompletionType):
                The completion topic.
            image_uri (str):
                The URI of the company image for
                [COMPANY_NAME][google.cloud.talent.v4.CompleteQueryRequest.CompletionType.COMPANY_NAME].
        """

        suggestion: str = proto.Field(
            proto.STRING,
            number=1,
        )
        type_: "CompleteQueryRequest.CompletionType" = proto.Field(
            proto.ENUM,
            number=2,
            enum="CompleteQueryRequest.CompletionType",
        )
        image_uri: str = proto.Field(
            proto.STRING,
            number=3,
        )

    completion_results: MutableSequence[CompletionResult] = proto.RepeatedField(
        proto.MESSAGE,
        number=1,
        message=CompletionResult,
    )
    metadata: common.ResponseMetadata = proto.Field(
        proto.MESSAGE,
        number=2,
        message=common.ResponseMetadata,
    )


__all__ = tuple(sorted(__protobuf__.manifest))



# -*- coding: utf-8 -*-
# Copyright 2022 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
from typing import MutableMapping, MutableSequence

import proto  # type: ignore

__protobuf__ = proto.module(
    package="google.cloud.talent.v4",
    manifest={
        "Tenant",
    },
)


class Tenant(proto.Message):
    r"""A Tenant resource represents a tenant in the service. A
    tenant is a group or entity that shares common access with
    specific privileges for resources like jobs. Customer may create
    multiple tenants to provide data isolation for different groups.

    Attributes:
        name (str):
            Required during tenant update.

            The resource name for a tenant. This is generated by the
            service when a tenant is created.

            The format is "projects/{project_id}/tenants/{tenant_id}",
            for example, "projects/foo/tenants/bar".
        external_id (str):
            Required. Client side tenant identifier, used
            to uniquely identify the tenant.
            The maximum number of allowed characters is 255.
    """

    name: str = proto.Field(
        proto.STRING,
        number=1,
    )
    external_id: str = proto.Field(
        proto.STRING,
        number=2,
    )


__all__ = tuple(sorted(__protobuf__.manifest))



# -*- coding: utf-8 -*-
# Copyright 2022 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
from typing import MutableMapping, MutableSequence

from google.protobuf import timestamp_pb2  # type: ignore
from google.protobuf import wrappers_pb2  # type: ignore
from google.type import latlng_pb2  # type: ignore
from google.type import money_pb2  # type: ignore
from google.type import postal_address_pb2  # type: ignore
import proto  # type: ignore

__protobuf__ = proto.module(
    package="google.cloud.talent.v4beta1",
    manifest={
        "CompanySize",
        "JobBenefit",
        "DegreeType",
        "EmploymentType",
        "JobLevel",
        "JobCategory",
        "PostingRegion",
        "Visibility",
        "HtmlSanitization",
        "CommuteMethod",
        "TimestampRange",
        "Location",
        "RequestMetadata",
        "ResponseMetadata",
        "DeviceInfo",
        "CustomAttribute",
        "SpellingCorrection",
        "CompensationInfo",
        "BatchOperationMetadata",
    },
)


class CompanySize(proto.Enum):
    r"""An enum that represents the size of the company."""
    COMPANY_SIZE_UNSPECIFIED = 0
    MINI = 1
    SMALL = 2
    SMEDIUM = 3
    MEDIUM = 4
    BIG = 5
    BIGGER = 6
    GIANT = 7


class JobBenefit(proto.Enum):
    r"""An enum that represents employee benefits included with the
    job.
    """
    JOB_BENEFIT_UNSPECIFIED = 0
    CHILD_CARE = 1
    DENTAL = 2
    DOMESTIC_PARTNER = 3
    FLEXIBLE_HOURS = 4
    MEDICAL = 5
    LIFE_INSURANCE = 6
    PARENTAL_LEAVE = 7
    RETIREMENT_PLAN = 8
    SICK_DAYS = 9
    VACATION = 10
    VISION = 11


class DegreeType(proto.Enum):
    r"""Educational degree level defined in International Standard
    Classification of Education (ISCED).
    """
    DEGREE_TYPE_UNSPECIFIED = 0
    PRIMARY_EDUCATION = 1
    LOWER_SECONDARY_EDUCATION = 2
    UPPER_SECONDARY_EDUCATION = 3
    ADULT_REMEDIAL_EDUCATION = 4
    ASSOCIATES_OR_EQUIVALENT = 5
    BACHELORS_OR_EQUIVALENT = 6
    MASTERS_OR_EQUIVALENT = 7
    DOCTORAL_OR_EQUIVALENT = 8


class EmploymentType(proto.Enum):
    r"""An enum that represents the employment type of a job."""
    EMPLOYMENT_TYPE_UNSPECIFIED = 0
    FULL_TIME = 1
    PART_TIME = 2
    CONTRACTOR = 3
    CONTRACT_TO_HIRE = 4
    TEMPORARY = 5
    INTERN = 6
    VOLUNTEER = 7
    PER_DIEM = 8
    FLY_IN_FLY_OUT = 9
    OTHER_EMPLOYMENT_TYPE = 10


class JobLevel(proto.Enum):
    r"""An enum that represents the required experience level
    required for the job.
    """
    JOB_LEVEL_UNSPECIFIED = 0
    ENTRY_LEVEL = 1
    EXPERIENCED = 2
    MANAGER = 3
    DIRECTOR = 4
    EXECUTIVE = 5


class JobCategory(proto.Enum):
    r"""An enum that represents the categorization or primary focus
    of specific role. This value is different than the "industry"
    associated with a role, which is related to the categorization
    of the company listing the job.
    """
    JOB_CATEGORY_UNSPECIFIED = 0
    ACCOUNTING_AND_FINANCE = 1
    ADMINISTRATIVE_AND_OFFICE = 2
    ADVERTISING_AND_MARKETING = 3
    ANIMAL_CARE = 4
    ART_FASHION_AND_DESIGN = 5
    BUSINESS_OPERATIONS = 6
    CLEANING_AND_FACILITIES = 7
    COMPUTER_AND_IT = 8
    CONSTRUCTION = 9
    CUSTOMER_SERVICE = 10
    EDUCATION = 11
    ENTERTAINMENT_AND_TRAVEL = 12
    FARMING_AND_OUTDOORS = 13
    HEALTHCARE = 14
    HUMAN_RESOURCES = 15
    INSTALLATION_MAINTENANCE_AND_REPAIR = 16
    LEGAL = 17
    MANAGEMENT = 18
    MANUFACTURING_AND_WAREHOUSE = 19
    MEDIA_COMMUNICATIONS_AND_WRITING = 20
    OIL_GAS_AND_MINING = 21
    PERSONAL_CARE_AND_SERVICES = 22
    PROTECTIVE_SERVICES = 23
    REAL_ESTATE = 24
    RESTAURANT_AND_HOSPITALITY = 25
    SALES_AND_RETAIL = 26
    SCIENCE_AND_ENGINEERING = 27
    SOCIAL_SERVICES_AND_NON_PROFIT = 28
    SPORTS_FITNESS_AND_RECREATION = 29
    TRANSPORTATION_AND_LOGISTICS = 30


class PostingRegion(proto.Enum):
    r"""An enum that represents the job posting region. In most
    cases, job postings don't need to specify a region. If a region
    is given, jobs are eligible for searches in the specified
    region.
    """
    POSTING_REGION_UNSPECIFIED = 0
    ADMINISTRATIVE_AREA = 1
    NATION = 2
    TELECOMMUTE = 3


class Visibility(proto.Enum):
    r"""Deprecated. All resources are only visible to the owner.
    An enum that represents who has view access to the resource.
    """
    _pb_options = {"deprecated": True}
    VISIBILITY_UNSPECIFIED = 0
    ACCOUNT_ONLY = 1
    SHARED_WITH_GOOGLE = 2
    SHARED_WITH_PUBLIC = 3


class HtmlSanitization(proto.Enum):
    r"""Option for HTML content sanitization on user input fields,
    for example, job description. By setting this option, user can
    determine whether and how sanitization is performed on these
    fields.
    """
    HTML_SANITIZATION_UNSPECIFIED = 0
    HTML_SANITIZATION_DISABLED = 1
    SIMPLE_FORMATTING_ONLY = 2


class CommuteMethod(proto.Enum):
    r"""Method for commute."""
    COMMUTE_METHOD_UNSPECIFIED = 0
    DRIVING = 1
    TRANSIT = 2
    WALKING = 3
    CYCLING = 4


class TimestampRange(proto.Message):
    r"""Message representing a period of time between two timestamps.

    Attributes:
        start_time (google.protobuf.timestamp_pb2.Timestamp):
            Begin of the period (inclusive).
        end_time (google.protobuf.timestamp_pb2.Timestamp):
            End of the period (exclusive).
    """

    start_time: timestamp_pb2.Timestamp = proto.Field(
        proto.MESSAGE,
        number=1,
        message=timestamp_pb2.Timestamp,
    )
    end_time: timestamp_pb2.Timestamp = proto.Field(
        proto.MESSAGE,
        number=2,
        message=timestamp_pb2.Timestamp,
    )


class Location(proto.Message):
    r"""A resource that represents a location with full geographic
    information.

    Attributes:
        location_type (google.cloud.talent_v4beta1.types.Location.LocationType):
            The type of a location, which corresponds to the address
            lines field of
            [google.type.PostalAddress][google.type.PostalAddress]. For
            example, "Downtown, Atlanta, GA, USA" has a type of
            [LocationType.NEIGHBORHOOD][google.cloud.talent.v4beta1.Location.LocationType.NEIGHBORHOOD],
            and "Kansas City, KS, USA" has a type of
            [LocationType.LOCALITY][google.cloud.talent.v4beta1.Location.LocationType.LOCALITY].
        postal_address (google.type.postal_address_pb2.PostalAddress):
            Postal address of the location that includes
            human readable information, such as postal
            delivery and payments addresses. Given a postal
            address, a postal service can deliver items to a
            premises, P.O. Box, or other delivery location.
        lat_lng (google.type.latlng_pb2.LatLng):
            An object representing a latitude/longitude
            pair.
        radius_miles (float):
            Radius in miles of the job location. This value is derived
            from the location bounding box in which a circle with the
            specified radius centered from
            [google.type.LatLng][google.type.LatLng] covers the area
            associated with the job location. For example, currently,
            "Mountain View, CA, USA" has a radius of 6.17 miles.
    """

    class LocationType(proto.Enum):
        r"""An enum which represents the type of a location."""
        LOCATION_TYPE_UNSPECIFIED = 0
        COUNTRY = 1
        ADMINISTRATIVE_AREA = 2
        SUB_ADMINISTRATIVE_AREA = 3
        LOCALITY = 4
        POSTAL_CODE = 5
        SUB_LOCALITY = 6
        SUB_LOCALITY_1 = 7
        SUB_LOCALITY_2 = 8
        NEIGHBORHOOD = 9
        STREET_ADDRESS = 10

    location_type: LocationType = proto.Field(
        proto.ENUM,
        number=1,
        enum=LocationType,
    )
    postal_address: postal_address_pb2.PostalAddress = proto.Field(
        proto.MESSAGE,
        number=2,
        message=postal_address_pb2.PostalAddress,
    )
    lat_lng: latlng_pb2.LatLng = proto.Field(
        proto.MESSAGE,
        number=3,
        message=latlng_pb2.LatLng,
    )
    radius_miles: float = proto.Field(
        proto.DOUBLE,
        number=4,
    )


class RequestMetadata(proto.Message):
    r"""Meta information related to the job searcher or entity
    conducting the job search. This information is used to improve
    the performance of the service.

    Attributes:
        domain (str):
            Required if
            [allow_missing_ids][google.cloud.talent.v4beta1.RequestMetadata.allow_missing_ids]
            is unset or ``false``.

            The client-defined scope or source of the service call,
            which typically is the domain on which the service has been
            implemented and is currently being run.

            For example, if the service is being run by client Foo,
            Inc., on job board www.foo.com and career site www.bar.com,
            then this field is set to "foo.com" for use on the job
            board, and "bar.com" for use on the career site.

            Note that any improvements to the model for a particular
            tenant site rely on this field being set correctly to a
            unique domain.

            The maximum number of allowed characters is 255.
        session_id (str):
            Required if
            [allow_missing_ids][google.cloud.talent.v4beta1.RequestMetadata.allow_missing_ids]
            is unset or ``false``.

            A unique session identification string. A session is defined
            as the duration of an end user's interaction with the
            service over a certain period. Obfuscate this field for
            privacy concerns before providing it to the service.

            Note that any improvements to the model for a particular
            tenant site rely on this field being set correctly to a
            unique session ID.

            The maximum number of allowed characters is 255.
        user_id (str):
            Required if
            [allow_missing_ids][google.cloud.talent.v4beta1.RequestMetadata.allow_missing_ids]
            is unset or ``false``.

            A unique user identification string, as determined by the
            client. To have the strongest positive impact on search
            quality make sure the client-level is unique. Obfuscate this
            field for privacy concerns before providing it to the
            service.

            Note that any improvements to the model for a particular
            tenant site rely on this field being set correctly to a
            unique user ID.

            The maximum number of allowed characters is 255.
        allow_missing_ids (bool):
            Only set when any of
            [domain][google.cloud.talent.v4beta1.RequestMetadata.domain],
            [session_id][google.cloud.talent.v4beta1.RequestMetadata.session_id]
            and
            [user_id][google.cloud.talent.v4beta1.RequestMetadata.user_id]
            isn't available for some reason. It is highly recommended
            not to set this field and provide accurate
            [domain][google.cloud.talent.v4beta1.RequestMetadata.domain],
            [session_id][google.cloud.talent.v4beta1.RequestMetadata.session_id]
            and
            [user_id][google.cloud.talent.v4beta1.RequestMetadata.user_id]
            for the best service experience.
        device_info (google.cloud.talent_v4beta1.types.DeviceInfo):
            The type of device used by the job seeker at
            the time of the call to the service.
    """

    domain: str = proto.Field(
        proto.STRING,
        number=1,
    )
    session_id: str = proto.Field(
        proto.STRING,
        number=2,
    )
    user_id: str = proto.Field(
        proto.STRING,
        number=3,
    )
    allow_missing_ids: bool = proto.Field(
        proto.BOOL,
        number=4,
    )
    device_info: "DeviceInfo" = proto.Field(
        proto.MESSAGE,
        number=5,
        message="DeviceInfo",
    )


class ResponseMetadata(proto.Message):
    r"""Additional information returned to client, such as debugging
    information.

    Attributes:
        request_id (str):
            A unique id associated with this call.
            This id is logged for tracking purposes.
    """

    request_id: str = proto.Field(
        proto.STRING,
        number=1,
    )


class DeviceInfo(proto.Message):
    r"""Device information collected from the job seeker, candidate,
    or other entity conducting the job search. Providing this
    information improves the quality of the search results across
    devices.

    Attributes:
        device_type (google.cloud.talent_v4beta1.types.DeviceInfo.DeviceType):
            Type of the device.
        id (str):
            A device-specific ID. The ID must be a unique
            identifier that distinguishes the device from
            other devices.
    """

    class DeviceType(proto.Enum):
        r"""An enumeration describing an API access portal and exposure
        mechanism.
        """
        DEVICE_TYPE_UNSPECIFIED = 0
        WEB = 1
        MOBILE_WEB = 2
        ANDROID = 3
        IOS = 4
        BOT = 5
        OTHER = 6

    device_type: DeviceType = proto.Field(
        proto.ENUM,
        number=1,
        enum=DeviceType,
    )
    id: str = proto.Field(
        proto.STRING,
        number=2,
    )


class CustomAttribute(proto.Message):
    r"""Custom attribute values that are either filterable or
    non-filterable.

    Attributes:
        string_values (MutableSequence[str]):
            Exactly one of
            [string_values][google.cloud.talent.v4beta1.CustomAttribute.string_values]
            or
            [long_values][google.cloud.talent.v4beta1.CustomAttribute.long_values]
            must be specified.

            This field is used to perform a string match
            (``CASE_SENSITIVE_MATCH`` or ``CASE_INSENSITIVE_MATCH``)
            search. For filterable ``string_value``\ s, a maximum total
            number of 200 values is allowed, with each ``string_value``
            has a byte size of no more than 500B. For unfilterable
            ``string_values``, the maximum total byte size of
            unfilterable ``string_values`` is 50KB.

            Empty string isn't allowed.
        long_values (MutableSequence[int]):
            Exactly one of
            [string_values][google.cloud.talent.v4beta1.CustomAttribute.string_values]
            or
            [long_values][google.cloud.talent.v4beta1.CustomAttribute.long_values]
            must be specified.

            This field is used to perform number range search. (``EQ``,
            ``GT``, ``GE``, ``LE``, ``LT``) over filterable
            ``long_value``.

            Currently at most 1
            [long_values][google.cloud.talent.v4beta1.CustomAttribute.long_values]
            is supported.
        filterable (bool):
            If the ``filterable`` flag is true, the custom field values
            may be used for custom attribute filters
            [JobQuery.custom_attribute_filter][google.cloud.talent.v4beta1.JobQuery.custom_attribute_filter].
            If false, these values may not be used for custom attribute
            filters.

            Default is false.
        keyword_searchable (bool):
            If the ``keyword_searchable`` flag is true, the keywords in
            custom fields are searchable by keyword match. If false, the
            values are not searchable by keyword match.

            Default is false.
    """

    string_values: MutableSequence[str] = proto.RepeatedField(
        proto.STRING,
        number=1,
    )
    long_values: MutableSequence[int] = proto.RepeatedField(
        proto.INT64,
        number=2,
    )
    filterable: bool = proto.Field(
        proto.BOOL,
        number=3,
    )
    keyword_searchable: bool = proto.Field(
        proto.BOOL,
        number=4,
    )


class SpellingCorrection(proto.Message):
    r"""Spell check result.

    Attributes:
        corrected (bool):
            Indicates if the query was corrected by the
            spell checker.
        corrected_text (str):
            Correction output consisting of the corrected
            keyword string.
        corrected_html (str):
            Corrected output with html tags to highlight
            the corrected words. Corrected words are called
            out with the "<b><i>...</i></b>" html tags.
            For example, the user input query is "software
            enginear", where the second word, "enginear," is
            incorrect. It should be "engineer". When
            spelling correction is enabled, this value is
            "software <b><i>engineer</i></b>".
    """

    corrected: bool = proto.Field(
        proto.BOOL,
        number=1,
    )
    corrected_text: str = proto.Field(
        proto.STRING,
        number=2,
    )
    corrected_html: str = proto.Field(
        proto.STRING,
        number=3,
    )


class CompensationInfo(proto.Message):
    r"""Job compensation details.

    Attributes:
        entries (MutableSequence[google.cloud.talent_v4beta1.types.CompensationInfo.CompensationEntry]):
            Job compensation information.

            At most one entry can be of type
            [CompensationInfo.CompensationType.BASE][google.cloud.talent.v4beta1.CompensationInfo.CompensationType.BASE],
            which is referred as **base compensation entry** for the
            job.
        annualized_base_compensation_range (google.cloud.talent_v4beta1.types.CompensationInfo.CompensationRange):
            Output only. Annualized base compensation range. Computed as
            base compensation entry's
            [CompensationEntry.amount][google.cloud.talent.v4beta1.CompensationInfo.CompensationEntry.amount]
            times
            [CompensationEntry.expected_units_per_year][google.cloud.talent.v4beta1.CompensationInfo.CompensationEntry.expected_units_per_year].

            See
            [CompensationEntry][google.cloud.talent.v4beta1.CompensationInfo.CompensationEntry]
            for explanation on compensation annualization.
        annualized_total_compensation_range (google.cloud.talent_v4beta1.types.CompensationInfo.CompensationRange):
            Output only. Annualized total compensation range. Computed
            as all compensation entries'
            [CompensationEntry.amount][google.cloud.talent.v4beta1.CompensationInfo.CompensationEntry.amount]
            times
            [CompensationEntry.expected_units_per_year][google.cloud.talent.v4beta1.CompensationInfo.CompensationEntry.expected_units_per_year].

            See
            [CompensationEntry][google.cloud.talent.v4beta1.CompensationInfo.CompensationEntry]
            for explanation on compensation annualization.
    """

    class CompensationType(proto.Enum):
        r"""The type of compensation.

        For compensation amounts specified in non-monetary amounts, describe
        the compensation scheme in the
        [CompensationEntry.description][google.cloud.talent.v4beta1.CompensationInfo.CompensationEntry.description].

        For example, tipping format is described in
        [CompensationEntry.description][google.cloud.talent.v4beta1.CompensationInfo.CompensationEntry.description]
        (for example, "expect 15-20% tips based on customer bill.") and an
        estimate of the tips provided in
        [CompensationEntry.amount][google.cloud.talent.v4beta1.CompensationInfo.CompensationEntry.amount]
        or
        [CompensationEntry.range][google.cloud.talent.v4beta1.CompensationInfo.CompensationEntry.range]
        ($10 per hour).

        For example, equity is described in
        [CompensationEntry.description][google.cloud.talent.v4beta1.CompensationInfo.CompensationEntry.description]
        (for example, "1% - 2% equity vesting over 4 years, 1 year cliff")
        and value estimated in
        [CompensationEntry.amount][google.cloud.talent.v4beta1.CompensationInfo.CompensationEntry.amount]
        or
        [CompensationEntry.range][google.cloud.talent.v4beta1.CompensationInfo.CompensationEntry.range].
        If no value estimate is possible, units are
        [CompensationUnit.COMPENSATION_UNIT_UNSPECIFIED][google.cloud.talent.v4beta1.CompensationInfo.CompensationUnit.COMPENSATION_UNIT_UNSPECIFIED]
        and then further clarified in
        [CompensationEntry.description][google.cloud.talent.v4beta1.CompensationInfo.CompensationEntry.description]
        field.
        """
        COMPENSATION_TYPE_UNSPECIFIED = 0
        BASE = 1
        BONUS = 2
        SIGNING_BONUS = 3
        EQUITY = 4
        PROFIT_SHARING = 5
        COMMISSIONS = 6
        TIPS = 7
        OTHER_COMPENSATION_TYPE = 8

    class CompensationUnit(proto.Enum):
        r"""Pay frequency."""
        COMPENSATION_UNIT_UNSPECIFIED = 0
        HOURLY = 1
        DAILY = 2
        WEEKLY = 3
        MONTHLY = 4
        YEARLY = 5
        ONE_TIME = 6
        OTHER_COMPENSATION_UNIT = 7

    class CompensationEntry(proto.Message):
        r"""A compensation entry that represents one component of compensation,
        such as base pay, bonus, or other compensation type.

        Annualization: One compensation entry can be annualized if

        -  it contains valid
           [amount][google.cloud.talent.v4beta1.CompensationInfo.CompensationEntry.amount]
           or
           [range][google.cloud.talent.v4beta1.CompensationInfo.CompensationEntry.range].
        -  and its
           [expected_units_per_year][google.cloud.talent.v4beta1.CompensationInfo.CompensationEntry.expected_units_per_year]
           is set or can be derived. Its annualized range is determined as
           ([amount][google.cloud.talent.v4beta1.CompensationInfo.CompensationEntry.amount]
           or
           [range][google.cloud.talent.v4beta1.CompensationInfo.CompensationEntry.range])
           times
           [expected_units_per_year][google.cloud.talent.v4beta1.CompensationInfo.CompensationEntry.expected_units_per_year].

        This message has `oneof`_ fields (mutually exclusive fields).
        For each oneof, at most one member field can be set at the same time.
        Setting any member of the oneof automatically clears all other
        members.

        .. _oneof: https://proto-plus-python.readthedocs.io/en/stable/fields.html#oneofs-mutually-exclusive-fields

        Attributes:
            type_ (google.cloud.talent_v4beta1.types.CompensationInfo.CompensationType):
                Compensation type.

                Default is
                [CompensationType.COMPENSATION_TYPE_UNSPECIFIED][google.cloud.talent.v4beta1.CompensationInfo.CompensationType.COMPENSATION_TYPE_UNSPECIFIED].
            unit (google.cloud.talent_v4beta1.types.CompensationInfo.CompensationUnit):
                Frequency of the specified amount.

                Default is
                [CompensationUnit.COMPENSATION_UNIT_UNSPECIFIED][google.cloud.talent.v4beta1.CompensationInfo.CompensationUnit.COMPENSATION_UNIT_UNSPECIFIED].
            amount (google.type.money_pb2.Money):
                Compensation amount.

                This field is a member of `oneof`_ ``compensation_amount``.
            range_ (google.cloud.talent_v4beta1.types.CompensationInfo.CompensationRange):
                Compensation range.

                This field is a member of `oneof`_ ``compensation_amount``.
            description (str):
                Compensation description.  For example, could
                indicate equity terms or provide additional
                context to an estimated bonus.
            expected_units_per_year (google.protobuf.wrappers_pb2.DoubleValue):
                Expected number of units paid each year. If not specified,
                when
                [Job.employment_types][google.cloud.talent.v4beta1.Job.employment_types]
                is FULLTIME, a default value is inferred based on
                [unit][google.cloud.talent.v4beta1.CompensationInfo.CompensationEntry.unit].
                Default values:

                -  HOURLY: 2080
                -  DAILY: 260
                -  WEEKLY: 52
                -  MONTHLY: 12
                -  ANNUAL: 1
        """

        type_: "CompensationInfo.CompensationType" = proto.Field(
            proto.ENUM,
            number=1,
            enum="CompensationInfo.CompensationType",
        )
        unit: "CompensationInfo.CompensationUnit" = proto.Field(
            proto.ENUM,
            number=2,
            enum="CompensationInfo.CompensationUnit",
        )
        amount: money_pb2.Money = proto.Field(
            proto.MESSAGE,
            number=3,
            oneof="compensation_amount",
            message=money_pb2.Money,
        )
        range_: "CompensationInfo.CompensationRange" = proto.Field(
            proto.MESSAGE,
            number=4,
            oneof="compensation_amount",
            message="CompensationInfo.CompensationRange",
        )
        description: str = proto.Field(
            proto.STRING,
            number=5,
        )
        expected_units_per_year: wrappers_pb2.DoubleValue = proto.Field(
            proto.MESSAGE,
            number=6,
            message=wrappers_pb2.DoubleValue,
        )

    class CompensationRange(proto.Message):
        r"""Compensation range.

        Attributes:
            max_compensation (google.type.money_pb2.Money):
                The maximum amount of compensation. If left empty, the value
                is set to a maximal compensation value and the currency code
                is set to match the [currency
                code][google.type.Money.currency_code] of min_compensation.
            min_compensation (google.type.money_pb2.Money):
                The minimum amount of compensation. If left empty, the value
                is set to zero and the currency code is set to match the
                [currency code][google.type.Money.currency_code] of
                max_compensation.
        """

        max_compensation: money_pb2.Money = proto.Field(
            proto.MESSAGE,
            number=2,
            message=money_pb2.Money,
        )
        min_compensation: money_pb2.Money = proto.Field(
            proto.MESSAGE,
            number=1,
            message=money_pb2.Money,
        )

    entries: MutableSequence[CompensationEntry] = proto.RepeatedField(
        proto.MESSAGE,
        number=1,
        message=CompensationEntry,
    )
    annualized_base_compensation_range: CompensationRange = proto.Field(
        proto.MESSAGE,
        number=2,
        message=CompensationRange,
    )
    annualized_total_compensation_range: CompensationRange = proto.Field(
        proto.MESSAGE,
        number=3,
        message=CompensationRange,
    )


class BatchOperationMetadata(proto.Message):
    r"""Metadata used for long running operations returned by CTS batch
    APIs. It's used to replace
    [google.longrunning.Operation.metadata][google.longrunning.Operation.metadata].

    Attributes:
        state (google.cloud.talent_v4beta1.types.BatchOperationMetadata.State):
            The state of a long running operation.
        state_description (str):
            More detailed information about operation
            state.
        success_count (int):
            Count of successful item(s) inside an
            operation.
        failure_count (int):
            Count of failed item(s) inside an operation.
        total_count (int):
            Count of total item(s) inside an operation.
        create_time (google.protobuf.timestamp_pb2.Timestamp):
            The time when the batch operation is created.
        update_time (google.protobuf.timestamp_pb2.Timestamp):
            The time when the batch operation status is updated. The
            metadata and the
            [update_time][google.cloud.talent.v4beta1.BatchOperationMetadata.update_time]
            is refreshed every minute otherwise cached data is returned.
        end_time (google.protobuf.timestamp_pb2.Timestamp):
            The time when the batch operation is finished and
            [google.longrunning.Operation.done][google.longrunning.Operation.done]
            is set to ``true``.
    """

    class State(proto.Enum):
        r""""""
        STATE_UNSPECIFIED = 0
        INITIALIZING = 1
        PROCESSING = 2
        SUCCEEDED = 3
        FAILED = 4
        CANCELLING = 5
        CANCELLED = 6

    state: State = proto.Field(
        proto.ENUM,
        number=1,
        enum=State,
    )
    state_description: str = proto.Field(
        proto.STRING,
        number=2,
    )
    success_count: int = proto.Field(
        proto.INT32,
        number=3,
    )
    failure_count: int = proto.Field(
        proto.INT32,
        number=4,
    )
    total_count: int = proto.Field(
        proto.INT32,
        number=5,
    )
    create_time: timestamp_pb2.Timestamp = proto.Field(
        proto.MESSAGE,
        number=6,
        message=timestamp_pb2.Timestamp,
    )
    update_time: timestamp_pb2.Timestamp = proto.Field(
        proto.MESSAGE,
        number=7,
        message=timestamp_pb2.Timestamp,
    )
    end_time: timestamp_pb2.Timestamp = proto.Field(
        proto.MESSAGE,
        number=8,
        message=timestamp_pb2.Timestamp,
    )


__all__ = tuple(sorted(__protobuf__.manifest))



# -*- coding: utf-8 -*-
# Copyright 2022 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
from typing import MutableMapping, MutableSequence

import proto  # type: ignore

from google.cloud.talent_v4.types import event

__protobuf__ = proto.module(
    package="google.cloud.talent.v4",
    manifest={
        "CreateClientEventRequest",
    },
)


class CreateClientEventRequest(proto.Message):
    r"""The report event request.

    Attributes:
        parent (str):
            Required. Resource name of the tenant under which the event
            is created.

            The format is "projects/{project_id}/tenants/{tenant_id}",
            for example, "projects/foo/tenants/bar".
        client_event (google.cloud.talent_v4.types.ClientEvent):
            Required. Events issued when end user
            interacts with customer's application that uses
            Cloud Talent Solution.
    """

    parent: str = proto.Field(
        proto.STRING,
        number=1,
    )
    client_event: event.ClientEvent = proto.Field(
        proto.MESSAGE,
        number=2,
        message=event.ClientEvent,
    )


__all__ = tuple(sorted(__protobuf__.manifest))
